@@ -15,8 +15,8 @@
 
 
 header('Access-Control-Allow-Origin: *');
-header('Access-Control-Allow-Headers: Content-Type');
-header('Access-Control-Allow-Methods: POST');
+header('Access-Control-Allow-Headers: Content-Type,Authorization');
+header('Access-Control-Allow-Methods: POST,OPTIONS');
 header('Access-Control-Max-Age: 1000');
 
 if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
