@@ -1,21 +1,16 @@
 <?php declare(strict_types = 0);
 /*
-** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -73,7 +68,7 @@ class CControllerHostGroupDisable extends CController {
 		$updated = count($hosts);
 
 		if ($result) {
-			$output['success']['title'] = _n('Host enabled', 'Hosts enabled', $updated);
+			$output['success']['title'] = _n('Host disabled', 'Hosts disabled', $updated);
 
 			if ($messages = get_and_clear_messages()) {
 				$output['success']['messages'] = array_column($messages, 'message');
@@ -88,7 +83,7 @@ class CControllerHostGroupDisable extends CController {
 			]);
 
 			$output['error'] = [
-				'title' => _n('Cannot enable host', 'Cannot enable hosts', $updated),
+				'title' => _n('Cannot disable host', 'Cannot disable hosts', $updated),
 				'messages' => array_column(get_and_clear_messages(), 'message'),
 				'keepids' => array_keys($hosts)
 			];
