@@ -121,6 +121,8 @@
 			if (dashboard.dashboardid === null) {
 				ZABBIX.Dashboard.editProperties();
 			}
+
+			this.setSubmitCallback();
 		},
 
 		save() {
@@ -132,9 +134,7 @@
 			const curl = new Curl('zabbix.php');
 
 			curl.setArgument('action', 'template.dashboard.update');
-			curl.setArgument('<?= CCsrfTokenHelper::CSRF_TOKEN_NAME ?>',
-				<?= json_encode(CCsrfTokenHelper::get('template')) ?>
-			);
+			curl.setArgument(CSRF_TOKEN_NAME, <?= json_encode(CCsrfTokenHelper::get('template')) ?>);
 
 			fetch(curl.getUrl(), {
 				method: 'POST',
@@ -208,21 +208,32 @@
 			window.removeEventListener('beforeunload', this.events.beforeUnload);
 		},
 
-		editTemplate(e, templateid) {
-			e.preventDefault();
-			const template_data = {templateid};
+		setSubmitCallback() {
+			window.popupManagerInstance.setSubmitCallback((e) => {
+				const data = e.detail;
+				let curl = null;
 
-			this.openTemplatePopup(template_data);
-		},
+				if ('success' in data) {
+					postMessageOk(data.success.title);
 
-		openTemplatePopup(template_data) {
-			const overlay =  PopUp('template.edit', template_data, {
-				dialogueid: 'templates-form',
-				dialogue_class: 'modal-popup-large',
-				prevent_navigation: true
+					if ('messages' in data.success) {
+						postMessageDetails('success', data.success.messages);
+					}
+
+					if ('action' in data.success && data.success.action === 'delete') {
+						curl = new Curl('zabbix.php');
+
+						curl.setArgument('action', 'template.list');
+					}
+				}
+
+				if (curl === null) {
+					location.href = location.href;
+				}
+				else {
+					location.href = curl.getUrl();
+				}
 			});
-
-			overlay.$dialogue[0].addEventListener('dialogue.submit', this.events.templateSuccess, {once: true});
 		},
 
 		events: {
@@ -286,31 +297,6 @@
 			idle() {
 				view.is_busy = false;
 				view.updateBusy();
-			},
-
-			templateSuccess(e) {
-				const data = e.detail;
-				let curl = null;
-
-				if ('success' in data) {
-					postMessageOk(data.success.title);
-
-					if ('messages' in data.success) {
-						postMessageDetails('success', data.success.messages);
-					}
-
-					if ('action' in data.success && data.success.action === 'delete') {
-						curl = new Curl('zabbix.php');
-						curl.setArgument('action', 'template.list');
-					}
-				}
-
-				if (curl == null) {
-					location.href = location.href;
-				}
-				else {
-					location.href = curl.getUrl();
-				}
 			}
 		}
 	}
