@@ -22,7 +22,7 @@
 window.drule_edit_popup = new class {
 
 	init({druleid, dchecks, drule}) {
-		this.overlay = overlays_stack.getById('discoveryForm');
+		this.overlay = overlays_stack.getById('discovery.edit');
 		this.dialogue = this.overlay.$dialogue[0];
 		this.form = this.overlay.$dialogue.$body[0].querySelector('form');
 
@@ -32,6 +32,11 @@ window.drule_edit_popup = new class {
 		this.dcheckid = getUniqueId();
 		this.available_device_types = [<?= SVC_AGENT ?>, <?= SVC_SNMPv1 ?>, <?= SVC_SNMPv2c ?>, <?= SVC_SNMPv3 ?>];
 
+		const backurl = new Curl('zabbix.php');
+
+		backurl.setArgument('action', 'discovery.list');
+		this.overlay.backurl = backurl.getUrl();
+
 		document.getElementById('discovery_by').addEventListener('change', () => this.#updateForm());
 
 		// Append existing discovery checks to check table.
@@ -372,7 +377,7 @@ window.drule_edit_popup = new class {
 		this.#post(curl.getUrl(), {druleids: [this.druleid]}, (response) => {
 			overlayDialogueDestroy(this.overlay.dialogueid);
 
-			this.dialogue.dispatchEvent(new CustomEvent('dialogue.submit', {detail: response.success}));
+			this.dialogue.dispatchEvent(new CustomEvent('dialogue.submit', {detail: response}));
 		});
 	}
 
@@ -389,7 +394,7 @@ window.drule_edit_popup = new class {
 		this.#post(curl.getUrl(), fields, (response) => {
 			overlayDialogueDestroy(this.overlay.dialogueid);
 
-			this.dialogue.dispatchEvent(new CustomEvent('dialogue.submit', {detail: response.success}));
+			this.dialogue.dispatchEvent(new CustomEvent('dialogue.submit', {detail: response}));
 		});
 	}
 
