@@ -27,62 +27,135 @@
 	const view = {
 		applied_filter_groupids: [],
 
-		init({applied_filter_groupids}) {
+		init({applied_filter_groupids, csrf_token}) {
 			this.applied_filter_groupids = applied_filter_groupids;
+			this.csrf_token = csrf_token;
 
 			this.initFilter();
 
-			document.addEventListener('click', (e) => {
-				if (e.target.classList.contains('js-edit-template')) {
-					this.editTemplate({templateid: e.target.dataset.templateid});
+			const form = document.forms['hosts'];
+
+			form.addEventListener('click', e => {
+				if (e.target.classList.contains('js-enable-host')) {
+					this.enable(e.target, {hostids: [e.target.dataset.hostid]});
 				}
-				else if (e.target.classList.contains('js-edit-proxy')) {
-					this.editProxy(e.target.dataset.proxyid);
-				}
-				else if (e.target.classList.contains('js-edit-proxy-group')) {
-					this.editProxyGroup(e.target.dataset.proxy_groupid);
+				else if (e.target.classList.contains('js-disable-host')) {
+					this.disable(e.target, {hostids: [e.target.dataset.hostid]});
 				}
 			});
-		},
 
-		editTemplate(parameters) {
-			const overlay = PopUp('template.edit', parameters, {
-				dialogueid: 'templates-form',
-				dialogue_class: 'modal-popup-large',
-				prevent_navigation: true
+			document.querySelector('.js-create-host').addEventListener('click', () => {
+				window.popupManagerInstance.openPopup('host.edit',
+					this.applied_filter_groupids ? {groupids: this.applied_filter_groupids} : {}
+				);
 			});
 
-			overlay.$dialogue[0].addEventListener('dialogue.submit', (e) => this.reload(e.detail.success));
-		},
+			form.querySelector('.js-massenable-host').addEventListener('click', e => {
+				const hostids = Object.keys(chkbxRange.getSelectedIds());
 
-		editProxy(proxyid) {
-			const overlay = PopUp('popup.proxy.edit', {proxyid}, {
-				dialogueid: 'proxy_edit',
-				dialogue_class: 'modal-popup-static',
-				prevent_navigation: true
+				const message = hostids.length > 1
+					? <?= json_encode(_('Enable selected hosts?')) ?>
+					: <?= json_encode(_('Enable selected host?')) ?>;
+
+				if (window.confirm(message)) {
+					this.enable(e.target, {hostids});
+				}
 			});
 
-			overlay.$dialogue[0].addEventListener('dialogue.submit', (e) => this.reload(e.detail.success));
-		},
+			form.querySelector('.js-massdisable-host').addEventListener('click', e => {
+				const hostids = Object.keys(chkbxRange.getSelectedIds());
 
-		editProxyGroup(proxy_groupid) {
-			const overlay = PopUp('popup.proxygroup.edit', {proxy_groupid}, {
-				dialogueid: 'proxy-group-edit',
-				dialogue_class: 'modal-popup-static',
-				prevent_navigation: true
+				const message = hostids.length > 1
+					? <?= json_encode(_('Disable selected hosts?')) ?>
+					: <?= json_encode(_('Disable selected host?')) ?>;
+
+				if (window.confirm(message)) {
+					this.disable(e.target, {hostids});
+				}
 			});
 
-			overlay.$dialogue[0].addEventListener('dialogue.submit', (e) => this.reload(e.detail.success));
+			form.querySelector('.js-massupdate-host').addEventListener('click', e => {
+				openMassupdatePopup('popup.massupdate.host', {
+					[CSRF_TOKEN_NAME]: this.csrf_token
+				}, {
+					dialogue_class: 'modal-popup-static',
+					trigger_element: e.target
+				})
+			});
+
+			form.querySelector('.js-massdelete-host').addEventListener('click', e => {
+				this.massDeleteHosts(e.target);
+			});
+
+			this.setSubmitCallback();
 		},
 
-		reload(success) {
-			postMessageOk(success.title);
+		enable(target, parameters) {
+			const curl = new Curl('zabbix.php');
+			curl.setArgument('action', 'host.enable');
 
-			if ('messages' in success) {
-				postMessageDetails('success', success.messages);
+			target.classList.add('is-loading');
+
+			this.postAction(curl, parameters)
+				.then(response => this.reload(response))
+				.finally(() => {
+					target.classList.remove('is-loading');
+					target.blur();
+				});
+		},
+
+		disable(target, parameters) {
+			const curl = new Curl('zabbix.php');
+			curl.setArgument('action', 'host.disable');
+
+			target.classList.add('is-loading');
+
+			this.postAction(curl, parameters)
+				.then(response => this.reload(response))
+				.finally(() => {
+					target.classList.remove('is-loading');
+					target.blur();
+				});
+		},
+
+		postAction(curl, data) {
+			return fetch(curl.getUrl(), {
+				method: 'POST',
+				headers: {'Content-Type': 'application/json'},
+				body: JSON.stringify({
+					...data,
+					[CSRF_TOKEN_NAME]: this.csrf_token
+				})
+			})
+				.then(response => response.json())
+				.catch(() => {
+					clearMessages();
+
+					const message_box = makeMessageBox('bad', [<?= json_encode(_('Unexpected server error.')) ?>]);
+
+					addMessage(message_box);
+				});
+		},
+
+		reload(result) {
+			if ('error' in result) {
+				if ('title' in result.error) {
+					postMessageError(result.error.title);
+				}
+
+				postMessageDetails('error', result.error.messages);
+
+				uncheckTableRows('hosts', result.keepids ?? []);
 			}
+			else if ('success' in result) {
+				postMessageOk(result.success.title);
 
-			uncheckTableRows('hosts');
+				if ('messages' in result.success) {
+					postMessageDetails('success', result.success.messages);
+				}
+
+				uncheckTableRows('hosts');
+			}
 
 			location.href = location.href;
 		},
@@ -123,35 +196,6 @@
 				.trigger('change');
 		},
 
-		createHost() {
-			const host_data = this.applied_filter_groupids
-				? {groupids: this.applied_filter_groupids}
-				: {};
-
-			this.openHostPopup(host_data);
-		},
-
-		editHost(e, hostid) {
-			e.preventDefault();
-			const host_data = {hostid};
-
-			this.openHostPopup(host_data);
-		},
-
-		openHostPopup(host_data) {
-			const original_url = location.href;
-			const overlay = PopUp('popup.host.edit', host_data, {
-				dialogueid: 'host_edit',
-				dialogue_class: 'modal-popup-large',
-				prevent_navigation: true
-			});
-
-			overlay.$dialogue[0].addEventListener('dialogue.submit', this.events.elementSuccess, {once: true});
-			overlay.$dialogue[0].addEventListener('dialogue.close', () => {
-				history.replaceState({}, '', original_url);
-			}, {once: true});
-		},
-
 		massDeleteHosts(button) {
 			const confirm_text = Object.keys(chkbxRange.getSelectedIds()).length > 1
 				? <?= json_encode(_('Delete selected hosts?')) ?>
@@ -165,36 +209,15 @@
 
 			const curl = new Curl('zabbix.php');
 			curl.setArgument('action', 'host.massdelete');
-			curl.setArgument(CSRF_TOKEN_NAME, <?= json_encode(CCsrfTokenHelper::get('host')) ?>);
+			curl.setArgument(CSRF_TOKEN_NAME, this.csrf_token);
 
 			fetch(curl.getUrl(), {
 				method: 'POST',
 				headers: {'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8'},
 				body: urlEncodeData({hostids: Object.keys(chkbxRange.getSelectedIds())})
 			})
-				.then((response) => response.json())
-				.then((response) => {
-					if ('error' in response) {
-						if ('title' in response.error) {
-							postMessageError(response.error.title);
-						}
-
-						postMessageDetails('error', response.error.messages);
-
-						uncheckTableRows('hosts', response.keepids ?? []);
-					}
-					else if ('success' in response) {
-						postMessageOk(response.success.title);
-
-						if ('messages' in response.success) {
-							postMessageDetails('success', response.success.messages);
-						}
-
-						uncheckTableRows('hosts');
-					}
-
-					location.href = location.href;
-				})
+				.then(response => response.json())
+				.then(response => this.reload(response))
 				.catch(() => {
 					clearMessages();
 
@@ -207,21 +230,19 @@
 				});
 		},
 
-		events: {
-			elementSuccess(e) {
-				const data = e.detail;
+		setSubmitCallback() {
+			window.popupManagerInstance.setSubmitCallback((e) => {
+				if ('success' in e.detail) {
+					postMessageOk(e.detail.success.title);
 
-				if ('success' in data) {
-					postMessageOk(data.success.title);
-
-					if ('messages' in data.success) {
-						postMessageDetails('success', data.success.messages);
+					if ('messages' in e.detail.success) {
+						postMessageDetails('success', e.detail.success.messages);
 					}
 				}
 
 				uncheckTableRows('hosts');
 				location.href = location.href;
-			}
+			});
 		}
 	};
 </script>
