@@ -1,21 +1,16 @@
 <?php
 /*
-** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -53,6 +48,7 @@
 			this.host_view_form = $('form[name=host_view]');
 			this.running = true;
 			this.refresh();
+			this.setSubmitCallback();
 		},
 
 		initTabFilter(filter_options) {
@@ -211,7 +207,7 @@
 
 			this.clearLoading();
 
-			const messages = $(jqXHR.responseText).find('.msg-global');
+			const messages = $(jqXHR.responseText).find('.<?= ZBX_STYLE_MSG_GLOBAL ?>');
 
 			if (messages.length) {
 				this.host_view_form.html(messages);
@@ -251,40 +247,13 @@
 		},
 
 		createHost() {
-			const host_data = this.applied_filter_groupids
-				? {groupids: this.applied_filter_groupids}
-				: {};
-
-			this.openHostPopup(host_data);
+			window.popupManagerInstance.openPopup('host.edit',
+				this.applied_filter_groupids ? {groupids: this.applied_filter_groupids} : {}
+			);
 		},
 
-		editHost(hostid) {
-			this.openHostPopup({hostid});
-		},
-
-		openHostPopup(host_data) {
-			this._removePopupMessage();
-
-			const original_url = location.href;
-			const overlay = PopUp('popup.host.edit', host_data, {
-				dialogueid: 'host_edit',
-				dialogue_class: 'modal-popup-large',
-				prevent_navigation: true
-			});
-
-			this.unscheduleRefresh();
-
-			overlay.$dialogue[0].addEventListener('dialogue.create', this.events.hostSuccess, {once: true});
-			overlay.$dialogue[0].addEventListener('dialogue.update', this.events.hostSuccess, {once: true});
-			overlay.$dialogue[0].addEventListener('dialogue.delete', this.events.hostSuccess, {once: true});
-			overlay.$dialogue[0].addEventListener('overlay.close', () => {
-				history.replaceState({}, '', original_url);
-				this.scheduleRefresh();
-			}, {once: true});
-		},
-
-		events: {
-			hostSuccess(e) {
+		setSubmitCallback() {
+			window.popupManagerInstance.setSubmitCallback((e) => {
 				const data = e.detail;
 
 				if ('success' in data) {
@@ -299,7 +268,7 @@
 				}
 
 				view.reloadPartialAndTabCounters();
-			}
+			});
 		}
 	};
 </script>
