@@ -1,21 +1,16 @@
 <?php declare(strict_types = 0);
 /*
-** Zabbix
 ** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -97,7 +92,8 @@ $maintenance_list = (new CTableInfo())
 		make_sorting_header(_('Active till'), 'active_till', $data['sort'], $data['sortorder'], $view_url),
 		_('State'),
 		_('Description')
-	]);
+	])
+	->setPageNavigation($data['paging']);
 
 foreach ($data['maintenances'] as $maintenanceid => $maintenance) {
 	switch ($maintenance['status']) {
@@ -114,20 +110,30 @@ foreach ($data['maintenances'] as $maintenanceid => $maintenance) {
 			break;
 	}
 
+	$maintenance_url = (new CUrl('zabbix.php'))
+		->setArgument('action', 'popup')
+		->setArgument('popup', 'maintenance.edit')
+		->setArgument('maintenanceid', $maintenanceid)
+		->getUrl();
+
 	$maintenance_list->addRow([
 		$data['allowed_edit'] ? new CCheckBox('maintenanceids['.$maintenanceid.']', $maintenanceid) : null,
-		(new CLink($maintenance['name']))
-			->addClass('js-edit-maintenance')
-			->setAttribute('data-maintenanceid', $maintenanceid),
+		(new CCol(
+			(new CLink($maintenance['name'], $maintenance_url))
+				->setAttribute('data-maintenanceid', $maintenanceid)
+				->setAttribute('data-action', 'maintenance.edit')
+		))->addClass(ZBX_STYLE_WORDBREAK),
 		$maintenance['maintenance_type'] ? _('No data collection') : _('With data collection'),
 		zbx_date2str(DATE_TIME_FORMAT, $maintenance['active_since']),
 		zbx_date2str(DATE_TIME_FORMAT, $maintenance['active_till']),
 		$maintenance_status,
-		$maintenance['description']
+		(new CCol($maintenance['description']))
+			->addClass(ZBX_STYLE_WORDBREAK)
+			->addStyle('max-width: '.ZBX_TEXTAREA_BIG_WIDTH.'px;')
 	]);
 }
 
-$form->addItem([$maintenance_list, $data['paging']]);
+$form->addItem($maintenance_list);
 
 if ($data['allowed_edit']) {
 	$form->addItem(
@@ -136,7 +142,7 @@ if ($data['allowed_edit']) {
 				'content' => (new CSimpleButton(_('Delete')))
 					->addClass(ZBX_STYLE_BTN_ALT)
 					->addClass('js-massdelete-maintenance')
-					->addClass('no-chkbxrange')
+					->addClass('js-no-chkbxrange')
 			]
 		], 'maintenance')
 	);
