@@ -49,7 +49,7 @@ class CLocalApiClient extends CApiClient {
 	 * @param string $requestMethod  API method.
 	 * @param array  $params         API parameters.
 	 * @param array  $auth
-	 * @param int    $auth['type']   CJsonRpc::AUTH_TYPE_PARAM, CJsonRpc::AUTH_TYPE_HEADER, CJsonRpc::AUTH_TYPE_COOKIE
+	 * @param int    $auth['type']   CJsonRpc::AUTH_TYPE_HEADER, CJsonRpc::AUTH_TYPE_COOKIE
 	 * @param string $auth['auth']   Authentication token.
 	 *
 	 * @return CApiClientResponse
@@ -81,21 +81,12 @@ class CLocalApiClient extends CApiClient {
 		$requiresAuthentication = $this->requiresAuthentication($api, $method);
 
 		// check that no authentication token is passed to methods that don't require it
-		if (!$requiresAuthentication) {
-			if ($auth['type'] == CJsonRpc::AUTH_TYPE_COOKIE) {
-				$auth['auth'] = null;
-			}
+		if (!$requiresAuthentication && $auth['type'] != CJsonRpc::AUTH_TYPE_COOKIE && $auth['auth'] !== null) {
+			$error = _('The "%1$s.%2$s" method must be called without authorization header.');
+			$response->errorCode = ZBX_API_ERROR_PARAMETERS;
+			$response->errorMessage = _params($error, [$requestApi, $requestMethod]);
 
-			if ($auth['auth'] !== null) {
-				$error = $auth['type'] == CJsonRpc::AUTH_TYPE_HEADER
-					? _('The "%1$s.%2$s" method must be called without authorization header.')
-					: _('The "%1$s.%2$s" method must be called without the "auth" parameter.');
-
-				$response->errorCode = ZBX_API_ERROR_PARAMETERS;
-				$response->errorMessage = _params($error, [$requestApi, $requestMethod]);
-
-				return $response;
-			}
+			return $response;
 		}
 
 		$newTransaction = false;
