@@ -1,21 +1,16 @@
 <?php
 /*
-** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -28,6 +23,15 @@ class CItem extends CItemGeneral {
 	protected $tableAlias = 'i';
 	protected $sortColumns = ['itemid', 'name', 'key_', 'delay', 'history', 'trends', 'type', 'status'];
 
+	public const OUTPUT_FIELDS = ['itemid', 'type', 'snmp_oid', 'hostid', 'name', 'key_', 'delay', 'history', 'trends',
+		'status', 'value_type', 'trapper_hosts', 'units', 'logtimefmt', 'templateid', 'valuemapid', 'params',
+		'ipmi_sensor', 'authtype', 'username', 'password', 'publickey', 'privatekey', 'flags', 'interfaceid',
+		'description', 'inventory_link', 'jmx_endpoint', 'master_itemid', 'timeout', 'url', 'query_fields', 'posts',
+		'status_codes', 'follow_redirects', 'post_type', 'http_proxy', 'headers', 'retrieve_mode', 'request_method',
+		'output_format', 'ssl_cert_file', 'ssl_key_file', 'ssl_key_password', 'verify_peer', 'verify_host',
+		'allow_traps', 'state', 'error', 'parameters', 'lastclock', 'lastns', 'lastvalue', 'prevvalue', 'name_resolved'
+	];
+
 	/**
 	 * @inheritDoc
 	 */
@@ -40,32 +44,7 @@ class CItem extends CItemGeneral {
 		ZBX_PREPROC_THROTTLE_TIMED_VALUE, ZBX_PREPROC_SCRIPT, ZBX_PREPROC_PROMETHEUS_PATTERN,
 		ZBX_PREPROC_PROMETHEUS_TO_JSON, ZBX_PREPROC_CSV_TO_JSON, ZBX_PREPROC_STR_REPLACE,
 		ZBX_PREPROC_VALIDATE_NOT_SUPPORTED, ZBX_PREPROC_XML_TO_JSON, ZBX_PREPROC_SNMP_WALK_VALUE,
-		ZBX_PREPROC_SNMP_WALK_TO_JSON
-	];
-
-	/**
-	 * @inheritDoc
-	 */
-	protected const PREPROC_TYPES_WITH_PARAMS = [
-		ZBX_PREPROC_MULTIPLIER, ZBX_PREPROC_RTRIM, ZBX_PREPROC_LTRIM, ZBX_PREPROC_TRIM, ZBX_PREPROC_REGSUB,
-		ZBX_PREPROC_XPATH, ZBX_PREPROC_JSONPATH, ZBX_PREPROC_VALIDATE_RANGE, ZBX_PREPROC_VALIDATE_REGEX,
-		ZBX_PREPROC_VALIDATE_NOT_REGEX, ZBX_PREPROC_ERROR_FIELD_JSON, ZBX_PREPROC_ERROR_FIELD_XML,
-		ZBX_PREPROC_ERROR_FIELD_REGEX, ZBX_PREPROC_THROTTLE_TIMED_VALUE, ZBX_PREPROC_SCRIPT,
-		ZBX_PREPROC_PROMETHEUS_PATTERN, ZBX_PREPROC_PROMETHEUS_TO_JSON, ZBX_PREPROC_CSV_TO_JSON,
-		ZBX_PREPROC_STR_REPLACE, ZBX_PREPROC_SNMP_WALK_VALUE, ZBX_PREPROC_SNMP_WALK_TO_JSON
-	];
-
-	/**
-	 * @inheritDoc
-	 */
-	protected const PREPROC_TYPES_WITH_ERR_HANDLING = [
-		ZBX_PREPROC_MULTIPLIER, ZBX_PREPROC_REGSUB, ZBX_PREPROC_BOOL2DEC, ZBX_PREPROC_OCT2DEC, ZBX_PREPROC_HEX2DEC,
-		ZBX_PREPROC_DELTA_VALUE, ZBX_PREPROC_DELTA_SPEED, ZBX_PREPROC_XPATH, ZBX_PREPROC_JSONPATH,
-		ZBX_PREPROC_VALIDATE_RANGE, ZBX_PREPROC_VALIDATE_REGEX, ZBX_PREPROC_VALIDATE_NOT_REGEX,
-		ZBX_PREPROC_ERROR_FIELD_JSON, ZBX_PREPROC_ERROR_FIELD_XML, ZBX_PREPROC_ERROR_FIELD_REGEX,
-		ZBX_PREPROC_PROMETHEUS_PATTERN, ZBX_PREPROC_PROMETHEUS_TO_JSON, ZBX_PREPROC_CSV_TO_JSON,
-		ZBX_PREPROC_VALIDATE_NOT_SUPPORTED, ZBX_PREPROC_XML_TO_JSON, ZBX_PREPROC_SNMP_WALK_VALUE,
-		ZBX_PREPROC_SNMP_WALK_TO_JSON
+		ZBX_PREPROC_SNMP_WALK_TO_JSON, ZBX_PREPROC_SNMP_GET_VALUE
 	];
 
 	/**
@@ -74,7 +53,8 @@ class CItem extends CItemGeneral {
 	public const SUPPORTED_ITEM_TYPES = [
 		ITEM_TYPE_ZABBIX, ITEM_TYPE_TRAPPER, ITEM_TYPE_SIMPLE, ITEM_TYPE_INTERNAL, ITEM_TYPE_ZABBIX_ACTIVE,
 		ITEM_TYPE_EXTERNAL, ITEM_TYPE_DB_MONITOR, ITEM_TYPE_IPMI, ITEM_TYPE_SSH, ITEM_TYPE_TELNET, ITEM_TYPE_CALCULATED,
-		ITEM_TYPE_JMX, ITEM_TYPE_SNMPTRAP, ITEM_TYPE_DEPENDENT, ITEM_TYPE_HTTPAGENT, ITEM_TYPE_SNMP, ITEM_TYPE_SCRIPT
+		ITEM_TYPE_JMX, ITEM_TYPE_SNMPTRAP, ITEM_TYPE_DEPENDENT, ITEM_TYPE_HTTPAGENT, ITEM_TYPE_SNMP, ITEM_TYPE_SCRIPT,
+		ITEM_TYPE_BROWSER
 	];
 
 	/**
@@ -85,7 +65,8 @@ class CItem extends CItemGeneral {
 		ITEM_VALUE_TYPE_STR => ['valuemapid', 'inventory_link'],
 		ITEM_VALUE_TYPE_LOG => ['logtimefmt'],
 		ITEM_VALUE_TYPE_UINT64 => ['units', 'trends', 'valuemapid', 'inventory_link'],
-		ITEM_VALUE_TYPE_TEXT => ['inventory_link']
+		ITEM_VALUE_TYPE_TEXT => ['inventory_link'],
+		ITEM_VALUE_TYPE_BINARY => []
 	];
 
 	/**
@@ -107,8 +88,6 @@ class CItem extends CItemGeneral {
 	 * @return array|int item data as array or false if error
 	 */
 	public function get($options = []) {
-		$result = [];
-
 		$sqlParts = [
 			'select'	=> ['items' => 'i.itemid'],
 			'from'		=> ['items' => 'items i'],
@@ -169,20 +148,19 @@ class CItem extends CItemGeneral {
 
 		// editable + permission check
 		if (self::$userData['type'] != USER_TYPE_SUPER_ADMIN && !$options['nopermissions']) {
-			$permission = $options['editable'] ? PERM_READ_WRITE : PERM_READ;
-			$userGroups = getUserGroupsByUserId(self::$userData['userid']);
+			if (self::$userData['ugsetid'] == 0) {
+				return $options['countOutput'] ? '0' : [];
+			}
 
-			$sqlParts['where'][] = 'EXISTS ('.
-					'SELECT NULL'.
-					' FROM hosts_groups hgg'.
-						' JOIN rights r'.
-							' ON r.id=hgg.groupid'.
-								' AND '.dbConditionInt('r.groupid', $userGroups).
-					' WHERE i.hostid=hgg.hostid'.
-					' GROUP BY hgg.hostid'.
-					' HAVING MIN(r.permission)>'.PERM_DENY.
-						' AND MAX(r.permission)>='.zbx_dbstr($permission).
-					')';
+			$sqlParts['from'][] = 'host_hgset hh';
+			$sqlParts['from'][] = 'permission p';
+			$sqlParts['where'][] = 'i.hostid=hh.hostid';
+			$sqlParts['where'][] = 'hh.hgsetid=p.hgsetid';
+			$sqlParts['where'][] = 'p.ugsetid='.self::$userData['ugsetid'];
+
+			if ($options['editable']) {
+				$sqlParts['where'][] = 'p.permission='.PERM_READ_WRITE;
+			}
 		}
 
 		// itemids
@@ -245,11 +223,11 @@ class CItem extends CItemGeneral {
 			zbx_value2array($options['proxyids']);
 
 			$sqlParts['from']['hosts'] = 'hosts h';
-			$sqlParts['where'][] = dbConditionId('h.proxy_hostid', $options['proxyids']);
+			$sqlParts['where'][] = dbConditionId('h.proxyid', $options['proxyids']);
 			$sqlParts['where'][] = 'h.hostid=i.hostid';
 
 			if ($options['groupCount']) {
-				$sqlParts['group']['h'] = 'h.proxy_hostid';
+				$sqlParts['group']['h'] = 'h.proxyid';
 			}
 		}
 
@@ -328,6 +306,14 @@ class CItem extends CItemGeneral {
 				);
 			}
 
+			if (array_key_exists('name_resolved', $options['search']) && $options['search']['name_resolved'] !== null) {
+				zbx_db_search(
+					'item_rtname irn',
+					['search' => ['name_resolved' => $options['search']['name_resolved']]] + $options,
+					$sqlParts
+				);
+			}
+
 			zbx_db_search('items i', $options, $sqlParts);
 		}
 
@@ -352,6 +338,14 @@ class CItem extends CItemGeneral {
 				);
 			}
 
+			if (array_key_exists('name_resolved', $options['filter']) && $options['filter']['name_resolved'] !== null) {
+				$this->dbFilter(
+					'item_rtname irn',
+					['filter' => ['name_resolved' => $options['filter']['name_resolved']]] + $options,
+					$sqlParts
+				);
+			}
+
 			$this->dbFilter('items i', $options, $sqlParts);
 
 			if (isset($options['filter']['host'])) {
@@ -413,59 +407,50 @@ class CItem extends CItemGeneral {
 
 		$sqlParts = $this->applyQueryOutputOptions($this->tableName(), $this->tableAlias(), $options, $sqlParts);
 		$sqlParts = $this->applyQuerySortOptions($this->tableName(), $this->tableAlias(), $options, $sqlParts);
-		$res = DBselect(self::createSelectQueryFromParts($sqlParts), $sqlParts['limit']);
-		while ($item = DBfetch($res)) {
-			// Items share table with item prototypes. Therefore remove item unrelated fields.
-			unset($item['discover']);
-
-			if (!$options['countOutput']) {
-				$result[$item['itemid']] = $item;
-				continue;
-			}
-
-			if ($options['groupCount']) {
-				$result[] = $item;
-			}
-			else {
-				$result = $item['rowscount'];
-			}
-		}
+		$resource = DBselect(self::createSelectQueryFromParts($sqlParts), $sqlParts['limit']);
 
 		if ($options['countOutput']) {
-			return $result;
-		}
+			if ($options['groupCount']) {
+				$result = [];
 
-		if ($result) {
-			if (self::dbDistinct($sqlParts)) {
-				$result = $this->addNclobFieldValues($options, $result);
+				while ($item = DBfetch($resource)) {
+					$result[] = $item;
+				}
+
+				return $result;
 			}
 
-			$result = $this->addRelatedObjects($options, $result);
-			$result = $this->unsetExtraFields($result, ['hostid', 'interfaceid', 'value_type', 'valuemapid'],
-				$options['output']
-			);
-			$result = $this->unsetExtraFields($result, ['name_upper']);
+			return DBfetch($resource)['rowscount'];
 		}
 
+		$items = [];
+		$items_chunk = [];
+
+		do {
+			while ($item = DBfetch($resource)) {
+				$items_chunk[$item['itemid']] = $item;
+
+				if (count($items_chunk) == CItemGeneral::CHUNK_SIZE) {
+					break;
+				}
+			}
+
+			if (!$items_chunk) {
+				break;
+			}
+
+			$this->prepareChunkObjects($items_chunk, $options);
+
+			$items += $items_chunk;
+			$items_chunk = [];
+		} while ($item !== false);
+
 		// removing keys (hash -> array)
 		if (!$options['preservekeys']) {
-			$result = zbx_cleanHashes($result);
+			$items = array_values($items);
 		}
 
-		// Decode ITEM_TYPE_HTTPAGENT encoded fields.
-		foreach ($result as &$item) {
-			if (array_key_exists('query_fields', $item)) {
-				$query_fields = ($item['query_fields'] !== '') ? json_decode($item['query_fields'], true) : [];
-				$item['query_fields'] = json_last_error() ? [] : $query_fields;
-			}
-
-			if (array_key_exists('headers', $item)) {
-				$item['headers'] = self::headersStringToArray($item['headers']);
-			}
-		}
-		unset($item);
-
-		return $result;
+		return $items;
 	}
 
 	/**
@@ -487,6 +472,22 @@ class CItem extends CItemGeneral {
 		}
 	}
 
+	private function prepareChunkObjects(array &$items, array $options): void {
+		$items = $this->addRelatedObjects($options, $items);
+		$items = $this->unsetExtraFields($items, ['hostid', 'interfaceid', 'value_type', 'valuemapid'],
+			$options['output']
+		);
+		$items = $this->unsetExtraFields($items, ['name_upper']);
+
+		self::prepareItemsForApi($items, false);
+
+		foreach ($items as &$item) {
+			// Items share table with item prototypes. Therefore remove item unrelated fields.
+			unset($item['discover']);
+		}
+		unset($item);
+	}
+
 	/**
 	 * @param array $items
 	 *
@@ -530,7 +531,10 @@ class CItem extends CItemGeneral {
 			'name' =>			['type' => API_STRING_UTF8, 'flags' => API_REQUIRED | API_NOT_EMPTY, 'length' => DB::getFieldLength('items', 'name')],
 			'type' =>			['type' => API_INT32, 'flags' => API_REQUIRED, 'in' => implode(',', self::SUPPORTED_ITEM_TYPES)],
 			'key_' =>			['type' => API_ITEM_KEY, 'flags' => API_REQUIRED, 'length' => DB::getFieldLength('items', 'key_')],
-			'value_type' =>		['type' => API_INT32, 'flags' => API_REQUIRED, 'in' => implode(',', [ITEM_VALUE_TYPE_FLOAT, ITEM_VALUE_TYPE_STR, ITEM_VALUE_TYPE_LOG, ITEM_VALUE_TYPE_UINT64, ITEM_VALUE_TYPE_TEXT])],
+			'value_type' =>		['type' => API_MULTIPLE, 'rules' => [
+									['if' => ['field' => 'type', 'in' => ITEM_TYPE_DEPENDENT], 'type' => API_INT32, 'flags' => API_REQUIRED, 'in' => implode(',', [ITEM_VALUE_TYPE_FLOAT, ITEM_VALUE_TYPE_STR, ITEM_VALUE_TYPE_LOG, ITEM_VALUE_TYPE_UINT64, ITEM_VALUE_TYPE_TEXT, ITEM_VALUE_TYPE_BINARY])],
+									['else' => true, 'type' => API_INT32, 'flags' => API_REQUIRED, 'in' => implode(',', [ITEM_VALUE_TYPE_FLOAT, ITEM_VALUE_TYPE_STR, ITEM_VALUE_TYPE_LOG, ITEM_VALUE_TYPE_UINT64, ITEM_VALUE_TYPE_TEXT])]
+			]],
 			'units' =>			['type' => API_MULTIPLE, 'rules' => [
 									['if' => ['field' => 'value_type', 'in' => implode(',', [ITEM_VALUE_TYPE_FLOAT, ITEM_VALUE_TYPE_UINT64])], 'type' => API_STRING_UTF8, 'length' => DB::getFieldLength('items', 'units')],
 									['else' => true, 'type' => API_STRING_UTF8, 'in' => DB::getDefault('items', 'units')]
@@ -568,20 +572,23 @@ class CItem extends CItemGeneral {
 
 		self::checkUuidDuplicates($items);
 		self::checkDuplicates($items);
+		self::checkPreprocessingStepsDuplicates($items);
 		self::checkValueMaps($items);
 		self::checkInventoryLinks($items);
 		self::checkHostInterfaces($items);
 		self::checkDependentItems($items);
-		self::checkPreprocessingSteps($items);
 	}
 
 	/**
 	 * @param array $items
 	 */
 	public static function createForce(array &$items): void {
+		self::prepareItemsForDb($items);
 		$itemids = DB::insert('items', $items);
+		self::prepareItemsForApi($items);
 
 		$ins_items_rtdata = [];
+		$ins_items_rtname = [];
 		$host_statuses = [];
 
 		foreach ($items as &$item) {
@@ -589,6 +596,10 @@ class CItem extends CItemGeneral {
 
 			if (in_array($item['host_status'], [HOST_STATUS_MONITORED, HOST_STATUS_NOT_MONITORED])) {
 				$ins_items_rtdata[] = ['itemid' => $item['itemid']];
+				$ins_items_rtname[] = [
+					'itemid' => $item['itemid'],
+					'name_resolved' => $item['name']
+				];
 			}
 
 			$host_statuses[] = $item['host_status'];
@@ -600,6 +611,10 @@ class CItem extends CItemGeneral {
 			DB::insertBatch('item_rtdata', $ins_items_rtdata, false);
 		}
 
+		if ($ins_items_rtname) {
+			DB::insertBatch('item_rtname', $ins_items_rtname, false);
+		}
+
 		self::updateParameters($items);
 		self::updatePreprocessing($items);
 		self::updateTags($items);
@@ -653,10 +668,6 @@ class CItem extends CItemGeneral {
 			self::exception(ZBX_API_ERROR_PERMISSIONS, _('No permissions to referred object or it does not exist!'));
 		}
 
-		/*
-		 * The fields "headers" and "query_fields" in API are arrays, but there is necessary to get the values of these
-		 * fields as they stored in database.
-		 */
 		$db_items = DB::select('items', [
 			'output' => array_merge(['uuid', 'itemid', 'name', 'type', 'key_', 'value_type', 'units', 'history',
 				'trends', 'valuemapid', 'inventory_link', 'logtimefmt', 'description', 'status'
@@ -688,7 +699,7 @@ class CItem extends CItemGeneral {
 				$api_input_rules = self::getDiscoveredValidationRules();
 			}
 			else {
-				$item += array_intersect_key($db_item, array_flip(['value_type']));
+				$item += array_intersect_key($db_item, array_flip(['type', 'value_type']));
 
 				$api_input_rules = self::getValidationRules();
 			}
@@ -711,11 +722,11 @@ class CItem extends CItemGeneral {
 
 		self::checkUuidDuplicates($items, $db_items);
 		self::checkDuplicates($items, $db_items);
+		self::checkPreprocessingStepsDuplicates($items);
 		self::checkValueMaps($items, $db_items);
 		self::checkInventoryLinks($items, $db_items);
 		self::checkHostInterfaces($items, $db_items);
 		self::checkDependentItems($items, $db_items);
-		self::checkPreprocessingSteps($items);
 	}
 
 	/**
@@ -732,7 +743,10 @@ class CItem extends CItemGeneral {
 			'name' =>			['type' => API_STRING_UTF8, 'flags' => API_NOT_EMPTY, 'length' => DB::getFieldLength('items', 'name')],
 			'type' =>			['type' => API_INT32, 'in' => implode(',', self::SUPPORTED_ITEM_TYPES)],
 			'key_' =>			['type' => API_ITEM_KEY, 'length' => DB::getFieldLength('items', 'key_')],
-			'value_type' =>		['type' => API_INT32, 'in' => implode(',', [ITEM_VALUE_TYPE_FLOAT, ITEM_VALUE_TYPE_STR, ITEM_VALUE_TYPE_LOG, ITEM_VALUE_TYPE_UINT64, ITEM_VALUE_TYPE_TEXT])],
+			'value_type' =>		['type' => API_MULTIPLE, 'rules' => [
+									['if' => ['field' => 'type', 'in' => ITEM_TYPE_DEPENDENT], 'type' => API_INT32, 'in' => implode(',', [ITEM_VALUE_TYPE_FLOAT, ITEM_VALUE_TYPE_STR, ITEM_VALUE_TYPE_LOG, ITEM_VALUE_TYPE_UINT64, ITEM_VALUE_TYPE_TEXT, ITEM_VALUE_TYPE_BINARY])],
+									['else' => true, 'type' => API_INT32, 'in' => implode(',', [ITEM_VALUE_TYPE_FLOAT, ITEM_VALUE_TYPE_STR, ITEM_VALUE_TYPE_LOG, ITEM_VALUE_TYPE_UINT64, ITEM_VALUE_TYPE_TEXT])]
+			]],
 			'units' =>			['type' => API_MULTIPLE, 'rules' => [
 									['if' => ['field' => 'value_type', 'in' => implode(',', [ITEM_VALUE_TYPE_FLOAT, ITEM_VALUE_TYPE_UINT64])], 'type' => API_STRING_UTF8, 'length' => DB::getFieldLength('items', 'units')],
 									['else' => true, 'type' => API_STRING_UTF8, 'in' => DB::getDefault('items', 'units')]
@@ -823,16 +837,20 @@ class CItem extends CItemGeneral {
 	 */
 	public static function updateForce(array &$items, array &$db_items): void {
 		// Helps to avoid deadlocks.
-		CArrayHelper::sort($items, ['itemid'], ZBX_SORT_DOWN);
+		CArrayHelper::sort($items, ['itemid']);
 
 		self::addFieldDefaultsByType($items, $db_items);
 
 		$upd_items = [];
 		$upd_itemids = [];
+		$upd_items_rtname = [];
+		$upd_item_discoveries = [];
 
 		$internal_fields = array_flip(['itemid', 'type', 'key_', 'value_type', 'hostid', 'flags', 'host_status']);
 		$nested_object_fields = array_flip(['tags', 'preprocessing', 'parameters']);
 
+		self::prepareItemsForDb($items);
+
 		foreach ($items as $i => &$item) {
 			$upd_item = DB::getUpdatedValues('items', $item, $db_items[$item['itemid']]);
 
@@ -852,6 +870,20 @@ class CItem extends CItemGeneral {
 				}
 
 				$upd_itemids[$i] = $item['itemid'];
+
+				if (array_key_exists('name', $upd_item)
+						&& in_array($item['host_status'], [HOST_STATUS_MONITORED, HOST_STATUS_NOT_MONITORED])) {
+					$upd_items_rtname[] = [
+						'values' => ['name_resolved' => $upd_item['name']],
+						'where' => ['itemid' => $item['itemid']]
+					];
+				}
+
+				if (array_key_exists('flags', $item) && $item['flags'] == ZBX_FLAG_DISCOVERY_CREATED
+						&& array_key_exists('status', $item) && $item['status'] == ITEM_STATUS_DISABLED
+						&& $item['status'] != $db_items[$item['itemid']]['status']) {
+					$upd_item_discoveries[] = $item['itemid'];
+				}
 			}
 			else {
 				$item = array_intersect_key($item, $internal_fields + $nested_object_fields);
@@ -863,6 +895,17 @@ class CItem extends CItemGeneral {
 			DB::update('items', $upd_items);
 		}
 
+		if ($upd_items_rtname) {
+			DB::update('item_rtname', $upd_items_rtname);
+		}
+
+		if ($upd_item_discoveries) {
+			DB::update('item_discovery', [
+				'values' => ['disable_source' => ZBX_DISABLE_DEFAULT],
+				'where' => ['itemid' => $upd_item_discoveries]
+			]);
+		}
+
 		self::updateTags($items, $db_items, $upd_itemids);
 		self::updatePreprocessing($items, $db_items, $upd_itemids);
 		self::updateParameters($items, $db_items, $upd_itemids);
@@ -870,6 +913,9 @@ class CItem extends CItemGeneral {
 		$items = array_intersect_key($items, $upd_itemids);
 		$db_items = array_intersect_key($db_items, array_flip($upd_itemids));
 
+		self::prepareItemsForApi($items);
+		self::prepareItemsForApi($db_items);
+
 		self::addAuditLog(CAudit::ACTION_UPDATE, CAudit::RESOURCE_ITEM, $items, $db_items);
 	}
 
@@ -942,6 +988,7 @@ class CItem extends CItemGeneral {
 			return;
 		}
 
+		self::prepareItemsForApi($db_items);
 		self::addInternalFields($db_items);
 
 		$items = [];
@@ -949,7 +996,7 @@ class CItem extends CItemGeneral {
 		foreach ($db_items as $db_item) {
 			$item = array_intersect_key($db_item, array_flip(['itemid', 'type']));
 
-			if ($db_item['type'] == ITEM_TYPE_SCRIPT) {
+			if (in_array($db_item['type'], [ITEM_TYPE_SCRIPT, ITEM_TYPE_BROWSER])) {
 				$item += ['parameters' => []];
 			}
 
@@ -999,7 +1046,7 @@ class CItem extends CItemGeneral {
 			$item_indexes = array_flip(array_column($items, 'itemid'));
 
 			foreach ($items as $i => $item) {
-				if ($item['type'] == ITEM_TYPE_DEPENDENT) {
+				if ($item['type'] == ITEM_TYPE_DEPENDENT && array_key_exists($item['master_itemid'], $item_indexes)) {
 					$dep_items_to_link[$item_indexes[$item['master_itemid']]][$i] = $item;
 
 					unset($items[$i]);
@@ -1028,7 +1075,7 @@ class CItem extends CItemGeneral {
 	 * @param array $tpl_links
 	 * @param array $hostids
 	 */
-	protected static function inheritChunk(array $items, array $db_items, array $tpl_links, array $hostids): void {
+	private static function inheritChunk(array $items, array $db_items, array $tpl_links, array $hostids): void {
 		$items_to_link = [];
 		$items_to_update = [];
 
@@ -1266,9 +1313,11 @@ class CItem extends CItemGeneral {
 			] + $item;
 
 			$upd_item += [
+				'headers' => [],
 				'tags' => [],
 				'preprocessing' => [],
-				'parameters' => []
+				'parameters' => [],
+				'query_fields' => []
 			];
 
 			$upd_items[] = $upd_item;
@@ -1326,7 +1375,7 @@ class CItem extends CItemGeneral {
 
 		$result = DBselect(
 			'SELECT ii.itemid,ii.name,ii.type,ii.key_,ii.value_type,ii.templateid,ii.uuid,ii.valuemapid,ii.hostid,'.
-				'h.status AS host_status'.
+				'ii.flags,h.status AS host_status'.
 			' FROM items i,items ii,hosts h'.
 			' WHERE i.itemid=ii.templateid'.
 				' AND ii.hostid=h.hostid'.
@@ -1340,11 +1389,11 @@ class CItem extends CItemGeneral {
 		$db_items = [];
 		$i = 0;
 		$tpl_itemids = [];
+		$internal_fields = array_flip(['type', 'key_', 'value_type', 'hostid', 'flags', 'host_status']);
 
 		while ($row = DBfetch($result)) {
 			$item = [
 				'itemid' => $row['itemid'],
-				'type' => $row['type'],
 				'templateid' => 0
 			];
 
@@ -1357,12 +1406,14 @@ class CItem extends CItemGeneral {
 
 				if ($row['host_status'] == HOST_STATUS_TEMPLATE) {
 					$tpl_itemids[$i] = $row['itemid'];
-					$item += array_intersect_key($row,
-						array_flip(['key_', 'hostid', 'host_status', 'value_type'])
-					);
+					$item += array_intersect_key($row, $internal_fields);
 				}
 			}
 
+			if ($row['host_status'] != HOST_STATUS_TEMPLATE || $row['valuemapid'] == 0) {
+				unset($row['type']);
+			}
+
 			$items[$i++] = $item;
 			$db_items[$row['itemid']] = $row;
 		}
@@ -1715,42 +1766,43 @@ class CItem extends CItemGeneral {
 			$result = $relationMap->mapOne($result, $itemDiscoveries, 'itemDiscovery');
 		}
 
-		// adding history data
-		$requestedOutput = [];
-		if ($this->outputIsRequested('lastclock', $options['output'])) {
-			$requestedOutput['lastclock'] = true;
-		}
-		if ($this->outputIsRequested('lastns', $options['output'])) {
-			$requestedOutput['lastns'] = true;
-		}
-		if ($this->outputIsRequested('lastvalue', $options['output'])) {
-			$requestedOutput['lastvalue'] = true;
-		}
-		if ($this->outputIsRequested('prevvalue', $options['output'])) {
-			$requestedOutput['prevvalue'] = true;
-		}
-		if ($requestedOutput) {
+		$requested_output = array_filter([
+			'lastclock' => $this->outputIsRequested('lastclock', $options['output']),
+			'lastns' => $this->outputIsRequested('lastns', $options['output']),
+			'lastvalue' => $this->outputIsRequested('lastvalue', $options['output']),
+			'prevvalue' => $this->outputIsRequested('prevvalue', $options['output'])
+		]);
+
+		if ($requested_output) {
 			$history = Manager::History()->getLastValues($result, 2, timeUnitToSeconds(CSettingsHelper::get(
 				CSettingsHelper::HISTORY_PERIOD
 			)));
-			foreach ($result as &$item) {
-				$lastHistory = isset($history[$item['itemid']][0]) ? $history[$item['itemid']][0] : null;
-				$prevHistory = isset($history[$item['itemid']][1]) ? $history[$item['itemid']][1] : null;
-				$no_value = in_array($item['value_type'],
-						[ITEM_VALUE_TYPE_STR, ITEM_VALUE_TYPE_LOG, ITEM_VALUE_TYPE_TEXT]) ? '' : '0';
 
-				if (isset($requestedOutput['lastclock'])) {
-					$item['lastclock'] = $lastHistory ? $lastHistory['clock'] : '0';
-				}
-				if (isset($requestedOutput['lastns'])) {
-					$item['lastns'] = $lastHistory ? $lastHistory['ns'] : '0';
-				}
-				if (isset($requestedOutput['lastvalue'])) {
-					$item['lastvalue'] = $lastHistory ? $lastHistory['value'] : $no_value;
-				}
-				if (isset($requestedOutput['prevvalue'])) {
-					$item['prevvalue'] = $prevHistory ? $prevHistory['value'] : $no_value;
+			foreach ($result as &$item) {
+				$last_history = null;
+				$prev_history = null;
+				$no_value = in_array($item['value_type'], [ITEM_VALUE_TYPE_FLOAT, ITEM_VALUE_TYPE_UINT64]) ? '0' : '';
+
+				if (array_key_exists($item['itemid'], $history)) {
+					[$last_history, $prev_history] = $history[$item['itemid']] + [null, null];
+
+					if ($item['value_type'] == ITEM_VALUE_TYPE_BINARY) {
+						if ($last_history) {
+							$last_history['value'] = base64_encode($last_history['value']);
+						}
+
+						if ($prev_history) {
+							$prev_history['value'] = base64_encode($prev_history['value']);
+						}
+					}
 				}
+
+				$item += array_intersect_key([
+					'lastclock' => $last_history ? $last_history['clock'] : '0',
+					'lastns' => $last_history ? $last_history['ns'] : '0',
+					'lastvalue' => $last_history ? $last_history['value'] : $no_value,
+					'prevvalue' => $prev_history ? $prev_history['value'] : $no_value
+				], $requested_output);
 			}
 			unset($item);
 		}
@@ -1785,12 +1837,6 @@ class CItem extends CItemGeneral {
 	protected function applyQueryOutputOptions($tableName, $tableAlias, array $options, array $sqlParts) {
 		$sqlParts = parent::applyQueryOutputOptions($tableName, $tableAlias, $options, $sqlParts);
 
-		$upcased_index = array_search($tableAlias.'.name_upper', $sqlParts['select']);
-
-		if ($upcased_index !== false) {
-			unset($sqlParts['select'][$upcased_index]);
-		}
-
 		if ((!$options['countOutput'] && ($this->outputIsRequested('state', $options['output'])
 				|| $this->outputIsRequested('error', $options['output'])))
 				|| (is_array($options['search']) && array_key_exists('error', $options['search']))
@@ -1799,17 +1845,30 @@ class CItem extends CItemGeneral {
 			$sqlParts['left_table'] = ['alias' => $this->tableAlias, 'table' => $this->tableName];
 		}
 
+		if ((!$options['countOutput'] && $this->outputIsRequested('name_resolved', $options['output']))
+				|| (is_array($options['search']) && array_key_exists('name_resolved', $options['search']))
+				|| (is_array($options['filter']) && array_key_exists('name_resolved', $options['filter']))) {
+			$sqlParts['left_join'][] = ['alias' => 'irn', 'table' => 'item_rtname', 'using' => 'itemid'];
+			$sqlParts['left_table'] = ['alias' => $this->tableAlias, 'table' => $this->tableName];
+		}
+
 		if (!$options['countOutput']) {
 			if ($this->outputIsRequested('state', $options['output'])) {
 				$sqlParts = $this->addQuerySelect('ir.state', $sqlParts);
 			}
+
+			/*
+			 * Use SQL COALESCE function for template items, because they don't have records
+			 * in item_rtdata and item_rtname tables and DBFetch converts null to '0'.
+			 */
 			if ($this->outputIsRequested('error', $options['output'])) {
-				/*
-				 * SQL func COALESCE use for template items because they don't have record
-				 * in item_rtdata table and DBFetch convert null to '0'
-				 */
 				$sqlParts = $this->addQuerySelect(dbConditionCoalesce('ir.error', '', 'error'), $sqlParts);
 			}
+			if ($this->outputIsRequested('name_resolved', $options['output'])) {
+				$sqlParts = $this->addQuerySelect(dbConditionCoalesce('irn.name_resolved', '', 'name_resolved'),
+					$sqlParts
+				);
+			}
 
 			if ($options['selectHosts'] !== null) {
 				$sqlParts = $this->addQuerySelect('i.hostid', $sqlParts);
@@ -1840,10 +1899,10 @@ class CItem extends CItemGeneral {
 	 */
 	public static function deleteForce(array $db_items): void {
 		self::addInheritedItems($db_items);
-		self::addDependentItems($db_items, $del_ruleids, $db_item_prototypes);
+		self::addDependentItems($db_items, $db_lld_rules, $db_item_prototypes);
 
-		if ($del_ruleids) {
-			CDiscoveryRuleManager::delete($del_ruleids);
+		if ($db_lld_rules) {
+			CDiscoveryRule::deleteForce($db_lld_rules);
 		}
 
 		if ($db_item_prototypes) {
@@ -1866,6 +1925,7 @@ class CItem extends CItemGeneral {
 		DB::delete('item_parameter', ['itemid' => $del_itemids]);
 		DB::delete('item_preproc', ['itemid' => $del_itemids]);
 		DB::delete('item_rtdata', ['itemid' => $del_itemids]);
+		DB::delete('item_rtname', ['itemid' => $del_itemids]);
 		DB::delete('item_tag', ['itemid' => $del_itemids]);
 		DB::update('items', [
 			'values' => ['templateid' => 0, 'master_itemid' => 0],
@@ -1881,12 +1941,12 @@ class CItem extends CItemGeneral {
 	 * prototypes to the given appropriate variables.
 	 *
 	 * @param array      $db_items
-	 * @param array|null $del_ruleids
+	 * @param array|null $db_lld_rules
 	 * @param array|null $db_item_prototypes
 	 */
-	protected static function addDependentItems(array &$db_items, array &$del_ruleids = null,
+	protected static function addDependentItems(array &$db_items, array &$db_lld_rules = null,
 			array &$db_item_prototypes = null): void {
-		$del_ruleids = [];
+		$db_lld_rules = [];
 		$db_item_prototypes = [];
 
 		$master_itemids = array_keys($db_items);
@@ -1902,7 +1962,7 @@ class CItem extends CItemGeneral {
 
 			while ($row = DBfetch($result)) {
 				if ($row['flags'] == ZBX_FLAG_DISCOVERY_RULE) {
-					$del_ruleids[] = $row['itemid'];
+					$db_lld_rules[$row['itemid']] = array_diff_key($row, array_flip(['flags']));
 				}
 				elseif ($row['flags'] == ZBX_FLAG_DISCOVERY_PROTOTYPE) {
 					$master_itemids[] = $row['itemid'];
@@ -1971,7 +2031,7 @@ class CItem extends CItemGeneral {
 
 		if (CHousekeepingHelper::get(CHousekeepingHelper::HK_HISTORY_MODE) == 1
 				&& (!$timescale_extension || CHousekeepingHelper::get(CHousekeepingHelper::HK_HISTORY_GLOBAL) == 0)) {
-			array_push($table_names, 'history', 'history_log', 'history_str', 'history_text', 'history_uint');
+			$table_names = array_merge($table_names, CHistoryManager::getTableName());
 		}
 
 		if (CHousekeepingHelper::get(CHousekeepingHelper::HK_TRENDS_MODE) == 1
