@@ -296,7 +296,7 @@ class CItemPrototype extends CItemGeneral {
 				break;
 			}
 
-			$this->prepareChunkObjects($items_chunk, $options, $sqlParts);
+			$this->prepareChunkObjects($items_chunk, $options);
 
 			$items += $items_chunk;
 			$items_chunk = [];
@@ -328,11 +328,7 @@ class CItemPrototype extends CItemGeneral {
 		}
 	}
 
-	private function prepareChunkObjects(array &$items, array $options, array $sqlParts): void {
-		if (self::dbDistinct($sqlParts)) {
-			$items = $this->addNclobFieldValues($options, $items);
-		}
-
+	private function prepareChunkObjects(array &$items, array $options): void {
 		$items = $this->addRelatedObjects($options, $items);
 		$items = $this->unsetExtraFields($items, ['hostid', 'valuemapid'], $options['output']);
 		$items = $this->unsetExtraFields($items, ['name_upper']);
