@@ -1,21 +1,16 @@
 <?php declare(strict_types = 0);
 /*
-** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -35,6 +30,8 @@ class CRole extends CApiService {
 	protected $tableAlias = 'r';
 	protected $sortColumns = ['roleid', 'name'];
 
+	public const OUTPUT_FIELDS = ['roleid', 'name', 'type', 'readonly'];
+
 	/**
 	 * Rule types.
 	 */
@@ -71,7 +68,7 @@ class CRole extends CApiService {
 			'excludeSearch' =>			['type' => API_FLAG, 'default' => false],
 			'searchWildcardsEnabled' =>	['type' => API_BOOLEAN, 'default' => false],
 			// output
-			'output' =>					['type' => API_OUTPUT, 'in' => implode(',', ['roleid', 'name', 'type', 'readonly']), 'default' => API_OUTPUT_EXTEND],
+			'output' =>					['type' => API_OUTPUT, 'in' => implode(',', self::OUTPUT_FIELDS), 'default' => API_OUTPUT_EXTEND],
 			'countOutput' =>			['type' => API_FLAG, 'default' => false],
 			'selectRules' =>			['type' => API_OUTPUT, 'flags' => API_ALLOW_NULL, 'in' => implode(',', ['ui', 'ui.default_access', 'services.read.mode', 'services.read.list', 'services.read.tag', 'services.write.mode', 'services.write.list', 'services.write.tag', 'modules', 'modules.default_access', 'api.access', 'api.mode', 'api', 'actions', 'actions.default_access']), 'default' => null],
 			'selectUsers' =>			['type' => API_OUTPUT, 'flags' => API_ALLOW_NULL | API_ALLOW_COUNT, 'in' => implode(',', ['userid', 'username', 'name', 'surname', 'url', 'autologin', 'autologout', 'lang', 'refresh', 'theme', 'attempt_failed', 'attempt_ip', 'attempt_clock', 'rows_per_page', 'timezone', 'roleid']), 'default' => null],
@@ -245,6 +242,7 @@ class CRole extends CApiService {
 
 		$roles = array_column($roles, null, 'roleid');
 
+		self::updateUserUgSets($roles, $db_roles);
 		$this->updateRules($roles, $db_roles);
 
 		$this->addAuditBulk(CAudit::ACTION_UPDATE, CAudit::RESOURCE_USER_ROLE, $roles, $db_roles);
@@ -422,15 +420,15 @@ class CRole extends CApiService {
 				continue;
 			}
 
-			$name = $db_roles !== null ? $db_roles[$role['roleid']]['name'] : $role['name'];
+			$name = array_key_exists('name', $role) ? $role['name'] : $db_roles[$role['roleid']]['name'];
 			$type = array_key_exists('type', $role) ? $role['type'] : $db_roles[$role['roleid']]['type'];
 
 			$db_rules = $db_roles !== null ? $db_roles[$role['roleid']]['rules'] : null;
 
-			$this->checkUiRules($name, (int) $type, $role['rules'], $db_rules);
+			self::checkUiRules($name, (int) $type, $role['rules'], $db_rules);
 			$this->checkServicesRules($name, (int) $type, $role['rules'], $db_rules);
 			$this->checkModulesRules($name, $role['rules']);
-			$this->checkApiRules($name, $role['rules']);
+			self::checkApiRules($name, (int) $type, $role['rules']);
 			$this->checkActionsRules($name, (int) $type, $role['rules']);
 		}
 	}
@@ -443,7 +441,7 @@ class CRole extends CApiService {
 
 	 * @throws APIException
 	 */
-	private function checkUiRules(string $name, int $type, array $rules, array $db_rules = null): void {
+	private static function checkUiRules(string $name, int $type, array $rules, array $db_rules = null): void {
 		if (!array_key_exists('ui', $rules)) {
 			return;
 		}
@@ -459,10 +457,13 @@ class CRole extends CApiService {
 		}
 
 		$ui_rules = [];
+		$db_ui_rules = $db_rules !== null ? array_column($db_rules['ui'], 'status', 'name') : [];
 
 		foreach (CRoleHelper::getUiElementsByUserType($type) as $ui_element) {
 			$ui_rule_name = substr($ui_element, strlen('ui.'));
-			$ui_rules[$ui_rule_name] = $default_access == ZBX_ROLE_RULE_ENABLED;
+			$ui_rules[$ui_rule_name] = array_key_exists($ui_rule_name, $db_ui_rules)
+				? $db_ui_rules[$ui_rule_name]
+				: $default_access;
 		}
 
 		foreach ($rules['ui'] as $ui_rule) {
@@ -472,10 +473,10 @@ class CRole extends CApiService {
 				);
 			}
 
-			$ui_rules[$ui_rule['name']] = $ui_rule['status'] == ZBX_ROLE_RULE_ENABLED;
+			$ui_rules[$ui_rule['name']] = $ui_rule['status'];
 		}
 
-		if (!in_array(true, $ui_rules)) {
+		if (!in_array(ZBX_ROLE_RULE_ENABLED, $ui_rules)) {
 			self::exception(ZBX_API_ERROR_PARAMETERS,
 				_s('At least one UI element must be enabled for user role "%1$s".', $name)
 			);
@@ -700,7 +701,7 @@ class CRole extends CApiService {
 			return;
 		}
 
-		$unavailable_moduleids = array_diff(array_keys($moduleids), self::getEnabledModuleIds());
+		$unavailable_moduleids = array_diff(array_keys($moduleids), self::getModuleIds());
 
 		if ($unavailable_moduleids) {
 			self::exception(ZBX_API_ERROR_PARAMETERS,
@@ -711,11 +712,12 @@ class CRole extends CApiService {
 
 	/**
 	 * @param string $name
+	 * @param int    $type
 	 * @param array  $rules
 	 *
 	 * @throws APIException
 	 */
-	private function checkApiRules(string $name, array $rules): void {
+	private static function checkApiRules(string $name, int $type, array $rules): void {
 		if (!array_key_exists('api', $rules)) {
 			return;
 		}
@@ -725,8 +727,8 @@ class CRole extends CApiService {
 				continue;
 			}
 
-			if (!in_array($rule, CRoleHelper::getApiMethodMasks(USER_TYPE_SUPER_ADMIN), true)
-					&& !in_array($rule, CRoleHelper::getApiMethods(USER_TYPE_SUPER_ADMIN), true)) {
+			if (!in_array($rule, CRoleHelper::getApiMethodMasks($type), true)
+					&& !in_array($rule, CRoleHelper::getApiMethods($type), true)) {
 				self::exception(ZBX_API_ERROR_PARAMETERS,
 					_s('Invalid API method "%2$s" for user role "%1$s".', $name, $rule)
 				);
@@ -786,6 +788,49 @@ class CRole extends CApiService {
 		}
 	}
 
+	private function updateUserUgSets(array $roles, array $db_roles): void {
+		$role_indexes = [];
+
+		foreach ($roles as $i => $role) {
+			if (array_key_exists('type', $role) && $role['type'] != $db_roles[$role['roleid']]['type']
+					&& ($role['type'] == USER_TYPE_SUPER_ADMIN
+						|| $db_roles[$role['roleid']]['type'] == USER_TYPE_SUPER_ADMIN)) {
+				$role_indexes[$role['roleid']] = $i;
+			}
+		}
+
+		if (!$role_indexes) {
+			return;
+		}
+
+		$options = [
+			'output' => ['userid', 'username', 'roleid'],
+			'filter' => ['roleid' => array_keys($role_indexes)]
+		];
+		$result = DBselect(DB::makeSql('users', $options));
+
+		$users = [];
+		$db_users = [];
+
+		while ($row = DBfetch($result)) {
+			$users[] = [
+				'userid' => $row['userid'],
+				'role_type' => $roles[$role_indexes[$row['roleid']]]['type']
+			];
+
+			$db_users[$row['userid']] = [
+				'userid' => $row['userid'],
+				'username' => $row['username'],
+				'roleid' => $row['roleid'],
+				'role_type' => $db_roles[$row['roleid']]['type']
+			];
+		}
+
+		if ($users) {
+			CUser::updateFromRole($users, $db_users);
+		}
+	}
+
 	/**
 	 * @param array      $roles
 	 * @param array|null $db_roles
@@ -814,22 +859,17 @@ class CRole extends CApiService {
 		$rules = [];
 
 		foreach ($roles as $roleid => $role) {
-			if (!array_key_exists('rules', $role)) {
-				continue;
-			}
-
 			$type = array_key_exists('type', $role) ? $role['type'] : $db_roles[$role['roleid']]['type'];
-
 			$old_rules = $db_roles !== null ? $db_roles[$roleid]['rules'] : $default_rules;
-			$new_rules = $role['rules'] + $old_rules;
+			$new_rules = array_key_exists('rules', $role) ? $role['rules'] + $old_rules : $old_rules;
 
 			$rules[$roleid] = array_merge(
-				$this->compileUiRules((int) $type, $old_rules, $new_rules),
-				$this->compileServicesReadRules($new_rules),
-				$this->compileServicesWriteRules($new_rules),
-				$this->compileModulesRules($old_rules, $new_rules),
-				$this->compileApiRules($new_rules),
-				$this->compileActionsRules((int) $type, $old_rules, $new_rules)
+				self::compileUiRules((int) $type, $old_rules, $new_rules),
+				self::compileServicesReadRules($new_rules),
+				self::compileServicesWriteRules($new_rules),
+				self::compileModulesRules($old_rules, $new_rules),
+				self::compileApiRules((int) $type, $new_rules),
+				self::compileActionsRules((int) $type, $old_rules, $new_rules)
 			);
 		}
 
@@ -900,7 +940,7 @@ class CRole extends CApiService {
 	 *
 	 * @return array
 	 */
-	private function compileUiRules(int $type, array $old_rules, array $new_rules): array {
+	private static function compileUiRules(int $type, array $old_rules, array $new_rules): array {
 		$old_ui_rules = array_column($old_rules['ui'], null, 'name');
 		$new_ui_rules = array_column($new_rules['ui'], null, 'name');
 
@@ -926,7 +966,6 @@ class CRole extends CApiService {
 					'value' => $ui_rule_status
 				];
 			}
-
 		}
 
 		$compiled_rules[] = [
@@ -943,7 +982,7 @@ class CRole extends CApiService {
 	 *
 	 * @return array
 	 */
-	private function compileServicesReadRules(array $new_rules): array {
+	private static function compileServicesReadRules(array $new_rules): array {
 		$compiled_rules[] = [
 			'name' => 'services.read',
 			'type' => self::RULE_TYPE_INT32,
@@ -984,7 +1023,7 @@ class CRole extends CApiService {
 	 *
 	 * @return array
 	 */
-	private function compileServicesWriteRules(array $new_rules): array {
+	private static function compileServicesWriteRules(array $new_rules): array {
 		$compiled_rules[] = [
 			'name' => 'services.write',
 			'type' => self::RULE_TYPE_INT32,
@@ -1028,7 +1067,7 @@ class CRole extends CApiService {
 	 *
 	 * @throws APIException
 	 */
-	private function compileModulesRules(array $old_rules, array $new_rules): array {
+	private static function compileModulesRules(array $old_rules, array $new_rules): array {
 		$old_modules_rules = array_column($old_rules['modules'], null, 'moduleid');
 		$new_modules_rules = array_column($new_rules['modules'], null, 'moduleid');
 
@@ -1036,7 +1075,7 @@ class CRole extends CApiService {
 
 		$index = 0;
 
-		foreach (self::getEnabledModuleIds() as $moduleid) {
+		foreach (self::getModuleIds() as $moduleid) {
 			if (array_key_exists($moduleid, $new_modules_rules)) {
 				$module_status = $new_modules_rules[$moduleid]['status'];
 			}
@@ -1068,11 +1107,12 @@ class CRole extends CApiService {
 	}
 
 	/**
+	 * @param int   $type
 	 * @param array $new_rules
 	 *
 	 * @return array
 	 */
-	private function compileApiRules(array $new_rules): array {
+	private static function compileApiRules(int $type, array $new_rules): array {
 		$compiled_rules = [];
 
 		$compiled_rules[] = [
@@ -1089,6 +1129,13 @@ class CRole extends CApiService {
 			];
 
 			foreach ($new_rules['api'] as $index => $api_method) {
+				// Skip specific API methods that do not belong to new user in case of user type change.
+				if ($api_method !== ZBX_ROLE_RULE_API_WILDCARD && $api_method !== ZBX_ROLE_RULE_API_WILDCARD_ALIAS
+						&& !in_array($api_method, CRoleHelper::getApiMethodMasks($type), true)
+						&& !in_array($api_method, CRoleHelper::getApiMethods($type), true)) {
+					continue;
+				}
+
 				$compiled_rules[] = [
 					'name' => 'api.method.'.$index,
 					'type' => self::RULE_TYPE_STR,
@@ -1107,7 +1154,7 @@ class CRole extends CApiService {
 	 *
 	 * @return array
 	 */
-	private function compileActionsRules(int $type, array $old_rules, array $new_rules): array {
+	private static function compileActionsRules(int $type, array $old_rules, array $new_rules): array {
 		$old_actions_rules = array_column($old_rules['actions'], null, 'name');
 		$new_actions_rules = array_column($new_rules['actions'], null, 'name');
 
@@ -1133,7 +1180,6 @@ class CRole extends CApiService {
 					'value' => $action_rule_status
 				];
 			}
-
 		}
 
 		$compiled_rules[] = [
@@ -1154,7 +1200,7 @@ class CRole extends CApiService {
 	 * @return array
 	 */
 	protected function applyQueryFilterOptions($table_name, $table_alias, array $options, array $sql_parts): array {
-		$sqlParts = parent::applyQueryFilterOptions($table_name, $table_alias, $options, $sql_parts);
+		$sql_parts = parent::applyQueryFilterOptions($table_name, $table_alias, $options, $sql_parts);
 
 		if (self::$userData['type'] != USER_TYPE_SUPER_ADMIN) {
 			$sql_parts['from']['users'] = 'users u';
@@ -1162,7 +1208,7 @@ class CRole extends CApiService {
 			$sql_parts['where'][] = 'u.userid='.self::$userData['userid'];
 		}
 
-		return $sqlParts;
+		return $sql_parts;
 	}
 
 	/**
@@ -1417,7 +1463,7 @@ class CRole extends CApiService {
 		if (in_array('modules', $output, true)) {
 			$modules = [];
 
-			foreach (self::getEnabledModuleIds() as $moduleid) {
+			foreach (self::getModuleIds() as $moduleid) {
 				$modules[$moduleid] = [
 					'moduleid' => $moduleid,
 					'status' => $modules_default_access
@@ -1520,12 +1566,9 @@ class CRole extends CApiService {
 	 *
 	 * @throws APIException
 	 */
-	private static function getEnabledModuleIds(): array {
+	private static function getModuleIds(): array {
 		$modules = API::getApiService('module')->get([
 			'output' => [],
-			'filter' => [
-				'status' => MODULE_STATUS_ENABLED
-			],
 			'preservekeys' => true
 		], false);
 
