@@ -1,21 +1,16 @@
 <?php
 /*
-** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -23,8 +18,6 @@ class CJsonRpc {
 
 	const VERSION = '2.0';
 
-	public const AUTH_TYPE_FRONTEND = 0;
-	public const AUTH_TYPE_PARAM = 1;
 	public const AUTH_TYPE_HEADER = 2;
 	public const AUTH_TYPE_COOKIE = 3;
 
@@ -58,9 +51,11 @@ class CJsonRpc {
 	/**
 	 * Executes API requests.
 	 *
+	 * @param CHttpRequest $request
+	 *
 	 * @return string JSON encoded value
 	 */
-	public function execute() {
+	public function execute(CHttpRequest $request) {
 		if (json_last_error()) {
 			$this->jsonError([], '-32700', null, null, true);
 			return json_encode($this->_response[0], JSON_UNESCAPED_SLASHES);
@@ -76,21 +71,16 @@ class CJsonRpc {
 				continue;
 			}
 
-			$auth = [
-				'type' => self::AUTH_TYPE_PARAM,
-				'auth' => $call['auth']
-			];
-
 			list($api, $method) = explode('.', $call['method']) + [1 => ''];
 
-			$header = $this->getAuthorizationHeader();
-			if ($header !== null && strpos($header, ZBX_API_HEADER_AUTHENTICATE_PREFIX) === 0) {
+			$header = $request->getAuthBearerValue();
+			if ($header != null) {
 				$auth = [
 					'type' => self::AUTH_TYPE_HEADER,
-					'auth' => substr($header, strlen(ZBX_API_HEADER_AUTHENTICATE_PREFIX))
+					'auth' => $header
 				];
 			}
-			elseif ($call['auth'] === null) {
+			else {
 				$session = new CEncryptedCookieSession();
 
 				$auth = [
@@ -122,7 +112,6 @@ class CJsonRpc {
 			'jsonrpc' =>	['type' => API_STRING_UTF8, 'flags' => API_REQUIRED, 'in' => self::VERSION],
 			'method' =>		['type' => API_STRING_UTF8, 'flags' => API_REQUIRED],
 			'params' =>		['type' => API_JSONRPC_PARAMS, 'flags' => API_REQUIRED],
-			'auth' =>		['type' => API_STRING_UTF8, 'flags' => API_NOT_EMPTY | API_ALLOW_NULL | API_DEPRECATED, 'default' => null],
 			'id' =>			['type' => API_JSONRPC_ID]
 		]];
 
@@ -243,22 +232,4 @@ class CJsonRpc {
 			ZBX_API_ERROR_INTERNAL => '-32500'
 		];
 	}
-
-	private function getAuthorizationHeader(): ?string {
-		if (array_key_exists('Authorization', $_SERVER)) {
-			return $_SERVER['Authorization'];
-		}
-		elseif (array_key_exists('HTTP_AUTHORIZATION', $_SERVER)) {
-			return $_SERVER['HTTP_AUTHORIZATION'];
-		}
-		elseif (function_exists('getallheaders')) {
-			$headers = getallheaders();
-
-			if (array_key_exists('Authorization', $headers)) {
-				return $headers['Authorization'];
-			}
-		}
-
-		return null;
-	}
 }
