@@ -1,21 +1,16 @@
 <?php
 /*
-** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -31,7 +26,6 @@ class CConfigurationExportBuilder {
 	 */
 	public function __construct() {
 		$this->data['version'] = ZABBIX_EXPORT_VERSION;
-		$this->data['date'] = date(DATE_TIME_FORMAT_SECONDS_XML, time() - date('Z'));
 	}
 
 	/**
@@ -87,7 +81,7 @@ class CConfigurationExportBuilder {
 
 		$value = $has_data ? $row[$tag] : $default_value;
 
-		if (!$is_required && $has_data && $default_value == $value) {
+		if (!$is_required && $default_value == $value) {
 			return null;
 		}
 
@@ -142,8 +136,32 @@ class CConfigurationExportBuilder {
 			$store = [];
 
 			if ($type == XML_ARRAY) {
-				foreach ($rules as $tag => $rule) {
-					$value = self::buildArrayRow($rule, $row, $tag, $main_tag);
+				foreach ($rules as $tag => $tag_rules) {
+					while ($tag_rules['type'] & XML_MULTIPLE) {
+						$matched_multiple_rule = null;
+
+						foreach ($tag_rules['rules'] as $multiple_rule) {
+							if (self::multipleRuleMatched($multiple_rule, $row)) {
+								$multiple_rule['type'] = ($tag_rules['type'] & XML_REQUIRED) | $multiple_rule['type'];
+								$matched_multiple_rule =
+									$multiple_rule + array_intersect_key($tag_rules, array_flip(['default']));
+								break;
+							}
+						}
+
+						if ($matched_multiple_rule === null) {
+							// For use by developers. Do not translate.
+							throw new Exception('Incorrect XML_MULTIPLE validation rules.');
+						}
+
+						$tag_rules = $matched_multiple_rule;
+					}
+
+					if ($tag_rules['type'] & XML_IGNORE_TAG) {
+						continue;
+					}
+
+					$value = self::buildArrayRow($tag_rules, $row, $tag, $main_tag);
 
 					if ($value !== null) {
 						$store[$tag] = $value;
@@ -165,6 +183,22 @@ class CConfigurationExportBuilder {
 		return $result;
 	}
 
+	private static function multipleRuleMatched(array $multiple_rule, array $data): bool {
+		if (array_key_exists('else', $multiple_rule)) {
+			return true;
+		}
+		elseif (is_array($multiple_rule['if'])) {
+			$field_name = $multiple_rule['if']['tag'];
+
+			return array_key_exists($data[$field_name], $multiple_rule['if']['in']);
+		}
+		elseif ($multiple_rule['if'] instanceof Closure) {
+			return call_user_func($multiple_rule['if'], $data);
+		}
+
+		return false;
+	}
+
 	/**
 	 * Format template groups.
 	 *
@@ -286,11 +320,21 @@ class CConfigurationExportBuilder {
 		CArrayHelper::sort($templates, ['host']);
 
 		foreach ($templates as $template) {
+			$vendor = [];
+
+			if ($template['vendor_name'] !== '' && $template['vendor_version'] !== '') {
+				$vendor = [
+					'name' => $template['vendor_name'],
+					'version' => $template['vendor_version']
+				];
+			}
+
 			$result[] = [
 				'uuid' => $template['uuid'],
 				'template' => $template['host'],
 				'name' => $template['name'],
 				'description' => $template['description'],
+				'vendor' => $vendor,
 				'groups' => $this->formatGroups($template['templategroups']),
 				'items' => $this->formatItems($template['items'], $simple_triggers),
 				'discovery_rules' => $this->formatDiscoveryRules($template['discoveryRules']),
@@ -324,7 +368,9 @@ class CConfigurationExportBuilder {
 				'host' => $host['host'],
 				'name' => $host['name'],
 				'description' => $host['description'],
+				'monitored_by' => $host['monitored_by'],
 				'proxy' => $host['proxy'],
+				'proxy_group' => $host['proxy_group'],
 				'status' => $host['status'],
 				'ipmi_authtype' => $host['ipmi_authtype'],
 				'ipmi_privilege' => $host['ipmi_privilege'],
@@ -427,8 +473,8 @@ class CConfigurationExportBuilder {
 
 		CArrayHelper::sort($media_types, ['name']);
 
-		foreach ($media_types as $media_type) {
-			$result[] = [
+		foreach ($media_types as $i => $media_type) {
+			$result[$i] = [
 				'name' => $media_type['name'],
 				'type' => $media_type['type'],
 				'smtp_server' => $media_type['smtp_server'],
@@ -441,7 +487,7 @@ class CConfigurationExportBuilder {
 				'smtp_authentication' => $media_type['smtp_authentication'],
 				'username' => $media_type['username'],
 				'password' => $media_type['passwd'],
-				'content_type' => $media_type['content_type'],
+				'message_format' => $media_type['message_format'],
 				'script_name' => $media_type['exec_path'],
 				'parameters' => self::formatMediaTypeParameters($media_type),
 				'gsm_modem' => $media_type['gsm_modem'],
@@ -458,6 +504,10 @@ class CConfigurationExportBuilder {
 				'description' => $media_type['description'],
 				'message_templates' => self::formatMediaTypeMessageTemplates($media_type['message_templates'])
 			];
+
+			if ($media_type['type'] == MEDIA_TYPE_EMAIL) {
+				$result[$i] += ['provider' => $media_type['provider']];
+			}
 		}
 
 		return $result;
@@ -466,8 +516,6 @@ class CConfigurationExportBuilder {
 	/**
 	 * Format media type parameters.
 	 *
-	 * @static
-	 *
 	 * @param array $media_type
 	 *
 	 * @return array|string
@@ -475,7 +523,9 @@ class CConfigurationExportBuilder {
 	private static function formatMediaTypeParameters(array $media_type) {
 		switch ($media_type['type']) {
 			case MEDIA_TYPE_EXEC:
-				return explode("\n", substr($media_type['exec_params'], 0, -1));
+				CArrayHelper::sort($media_type['parameters'], ['sortorder']);
+
+				return array_values($media_type['parameters']);
 
 			case MEDIA_TYPE_WEBHOOK:
 				CArrayHelper::sort($media_type['parameters'], ['name']);
@@ -489,8 +539,6 @@ class CConfigurationExportBuilder {
 	/**
 	 * Format media type message templates.
 	 *
-	 * @static
-	 *
 	 * @param array $message_templates
 	 *
 	 * @return array
@@ -622,7 +670,10 @@ class CConfigurationExportBuilder {
 				'publickey' => $discoveryRule['publickey'],
 				'privatekey' => $discoveryRule['privatekey'],
 				'filter' => $discoveryRule['filter'],
+				'lifetime_type' => $discoveryRule['lifetime_type'],
 				'lifetime' => $discoveryRule['lifetime'],
+				'enabled_lifetime_type' => $discoveryRule['enabled_lifetime_type'],
+				'enabled_lifetime' => $discoveryRule['enabled_lifetime'],
 				'description' => $discoveryRule['description'],
 				'item_prototypes' => $this->formatItems($discoveryRule['itemPrototypes'], $simple_trigger_prototypes),
 				'trigger_prototypes' => $this->formatTriggers($discoveryRule['triggerPrototypes']),
@@ -632,7 +683,7 @@ class CConfigurationExportBuilder {
 				'timeout' => $discoveryRule['timeout'],
 				'url' => $discoveryRule['url'],
 				'query_fields' => $discoveryRule['query_fields'],
-				'parameters' => $discoveryRule['parameters'],
+				'parameters' => self::formatItemParameters($discoveryRule['parameters']),
 				'posts' => $discoveryRule['posts'],
 				'status_codes' => $discoveryRule['status_codes'],
 				'follow_redirects' => $discoveryRule['follow_redirects'],
@@ -647,38 +698,19 @@ class CConfigurationExportBuilder {
 				'ssl_key_password' => $discoveryRule['ssl_key_password'],
 				'verify_peer' => $discoveryRule['verify_peer'],
 				'verify_host' => $discoveryRule['verify_host'],
-				'lld_macro_paths' => $discoveryRule['lld_macro_paths'],
+				'lld_macro_paths' => self::formatLldMacroPaths($discoveryRule['lld_macro_paths']),
 				'preprocessing' => self::formatPreprocessingSteps($discoveryRule['preprocessing']),
-				'overrides' => $discoveryRule['overrides']
+				'overrides' => self::formatLldOverrides($discoveryRule['overrides'])
 			];
 
+			if (!$data['filter']['conditions']) {
+				unset($data['filter']);
+			}
+
 			if (isset($discoveryRule['interface_ref'])) {
 				$data['interface_ref'] = $discoveryRule['interface_ref'];
 			}
 
-			if ($discoveryRule['query_fields']) {
-				$query_fields = [];
-
-				foreach ($discoveryRule['query_fields'] as $query_field) {
-					$query_fields[] = [
-						'name' => key($query_field),
-						'value' => reset($query_field)
-					];
-				}
-
-				$data['query_fields'] = $query_fields;
-			}
-
-			if ($discoveryRule['headers']) {
-				$headers = [];
-
-				foreach ($discoveryRule['headers'] as $name => $value) {
-					$headers[] = compact('name', 'value');
-				}
-
-				$data['headers'] = $headers;
-			}
-
 			$data['master_item'] = ($discoveryRule['type'] == ITEM_TYPE_DEPENDENT)
 				? ['key' => $discoveryRule['master_item']['key_']]
 				: [];
@@ -689,13 +721,60 @@ class CConfigurationExportBuilder {
 		return $result;
 	}
 
+	/**
+	 * Format the LLD macro paths.
+	 *
+	 * @param array $lld_macro_paths
+	 *
+	 * @return array
+	 */
+	private static function formatLldMacroPaths(array $lld_macro_paths): array {
+		CArrayHelper::sort($lld_macro_paths, ['lld_macro']);
+
+		return array_values($lld_macro_paths);
+	}
+
+
+	/**
+	 * Format the LLD overrides contained in a discovery rule.
+	 *
+	 * @param array $overrides
+	 *
+	 * @return array
+	 */
+	private static function formatLldOverrides(array $overrides): array {
+		CArrayHelper::sort($overrides, ['step']);
+
+		foreach ($overrides as &$override) {
+			unset($override['filter']['eval_formula']);
+
+			if (!$override['filter']['conditions']) {
+				unset($override['filter']);
+			}
+
+			CArrayHelper::sort($override['operations'], ['operationobject', 'operator', 'value']);
+
+			foreach ($override['operations'] as &$operation) {
+				if (array_key_exists('tags', $operation)) {
+					CArrayHelper::sort($operation['tags'], ['tag', 'value']);
+				}
+
+				if (array_key_exists('templates', $operation)) {
+					CArrayHelper::sort($operation['templates'], ['name']);
+				}
+			}
+			unset($operation);
+		}
+		unset($override);
+
+		return array_values($overrides);
+	}
+
 	/**
 	 * Format preprocessing steps.
 	 *
 	 * @param array $preprocessing_steps
 	 *
-	 * @static
-	 *
 	 * @return array
 	 */
 	private static function formatPreprocessingSteps(array $preprocessing_steps) {
@@ -723,6 +802,8 @@ class CConfigurationExportBuilder {
 		order_result($httptests, 'name');
 
 		foreach ($httptests as $httptest) {
+			CArrayHelper::sort($httptest['variables'], ['name']);
+
 			$result[] = [
 				'uuid' => $httptest['uuid'],
 				'name' => $httptest['name'],
@@ -762,6 +843,8 @@ class CConfigurationExportBuilder {
 		order_result($httpsteps, 'no');
 
 		foreach ($httpsteps as $httpstep) {
+			CArrayHelper::sort($httpstep['variables'], ['name']);
+
 			$result[] = [
 				'name' => $httpstep['name'],
 				'url' => $httpstep['url'],
@@ -803,7 +886,29 @@ class CConfigurationExportBuilder {
 	protected function formatGraphs(array $graphs) {
 		$result = [];
 
-		CArrayHelper::sort($graphs, ['name']);
+		usort($graphs, static function (array $graph_a, array $graph_b): int {
+			$comparison = strnatcasecmp($graph_a['name'], $graph_b['name']);
+
+			if ($comparison != 0) {
+				return $comparison;
+			}
+
+			$graph_a_items = [];
+			$graph_b_items = [];
+
+			foreach ($graph_a['gitems'] as $gitem) {
+				$graph_a_items[] = $gitem['itemid'];
+			}
+
+			foreach ($graph_b['gitems'] as $gitem) {
+				$graph_b_items[] = $gitem['itemid'];
+			}
+
+			CArrayHelper::sort($graph_a_items, ['host']);
+			CArrayHelper::sort($graph_b_items, ['host']);
+
+			return strnatcasecmp(reset($graph_a_items)['host'], reset($graph_b_items)['host']);
+		});
 
 		foreach ($graphs as $graph) {
 			$data = [
@@ -958,6 +1063,7 @@ class CConfigurationExportBuilder {
 				'opdata' => $trigger['opdata'],
 				'correlation_mode' => $trigger['correlation_mode'],
 				'correlation_tag' => $trigger['correlation_tag'],
+				'url_name' => $trigger['url_name'],
 				'url' => $trigger['url'],
 				'status' => $trigger['status'],
 				'priority' => $trigger['priority'],
@@ -1105,7 +1211,7 @@ class CConfigurationExportBuilder {
 				'timeout' => $item['timeout'],
 				'url' => $item['url'],
 				'query_fields' => $item['query_fields'],
-				'parameters' => $item['parameters'],
+				'parameters' => self::formatItemParameters($item['parameters']),
 				'posts' => $item['posts'],
 				'status_codes' => $item['status_codes'],
 				'follow_redirects' => $item['follow_redirects'],
@@ -1136,29 +1242,6 @@ class CConfigurationExportBuilder {
 				$data['interface_ref'] = $item['interface_ref'];
 			}
 
-			if ($item['query_fields']) {
-				$query_fields = [];
-
-				foreach ($item['query_fields'] as $query_field) {
-					$query_fields[] = [
-						'name' => key($query_field),
-						'value' => reset($query_field)
-					];
-				}
-
-				$data['query_fields'] = $query_fields;
-			}
-
-			if ($item['headers']) {
-				$headers = [];
-
-				foreach ($item['headers'] as $name => $value) {
-					$headers[] = compact('name', 'value');
-				}
-
-				$data['headers'] = $headers;
-			}
-
 			if ($simple_triggers) {
 				$triggers = [];
 				foreach ($simple_triggers as $simple_trigger) {
@@ -1179,6 +1262,19 @@ class CConfigurationExportBuilder {
 		return $result;
 	}
 
+	/**
+	 * Format item parameters.
+	 *
+	 * @param array $parameters
+	 *
+	 * @return array
+	 */
+	private static function formatItemParameters(array $parameters): array {
+		CArrayHelper::sort($parameters, ['name']);
+
+		return array_values($parameters);
+	}
+
 	/**
 	 * Format macros.
 	 *
@@ -1306,7 +1402,7 @@ class CConfigurationExportBuilder {
 	protected function formatWidgets(array $widgets) {
 		$result = [];
 
-		CArrayHelper::sort($widgets, ['name']);
+		CArrayHelper::sort($widgets, ['x', 'y']);
 
 		foreach ($widgets as $widget) {
 			$result[] = [
@@ -1334,7 +1430,7 @@ class CConfigurationExportBuilder {
 	protected function formatWidgetFields(array $fields) {
 		$result = [];
 
-		CArrayHelper::sort($fields, ['type']);
+		self::sortWidgetFields($fields);
 
 		foreach ($fields as $field) {
 			$result[] = [
@@ -1347,6 +1443,58 @@ class CConfigurationExportBuilder {
 		return $result;
 	}
 
+	/**
+	 * Sorts widget fields taking into account expanded objects.
+	 *
+	 * @param array $fields
+	 */
+	private static function sortWidgetFields(array &$fields): void {
+		usort($fields, static function(array $widget_field_a, array $widget_field_b): int {
+			$comparison = strnatcasecmp($widget_field_a['name'], $widget_field_b['name']);
+
+			if ($comparison != 0) {
+				return $comparison;
+			}
+
+			$comparison = strnatcasecmp($widget_field_a['type'], $widget_field_b['type']);
+
+			if ($comparison != 0) {
+				return $comparison;
+			}
+
+			switch ($widget_field_a['type']) {
+				case ZBX_WIDGET_FIELD_TYPE_HOST:
+					$value_fields = ['host'];
+					break;
+
+				case ZBX_WIDGET_FIELD_TYPE_ITEM:
+				case ZBX_WIDGET_FIELD_TYPE_ITEM_PROTOTYPE:
+					$value_fields = ['host', 'key'];
+					break;
+
+				case ZBX_WIDGET_FIELD_TYPE_GRAPH:
+				case ZBX_WIDGET_FIELD_TYPE_GRAPH_PROTOTYPE:
+					$value_fields = ['host', 'name'];
+					break;
+
+				default:
+					return strnatcasecmp($widget_field_a['value'], $widget_field_b['value']);
+			}
+
+			foreach ($value_fields as $value_field) {
+				$comparison = strnatcasecmp($widget_field_a['value'][$value_field],
+					$widget_field_b['value'][$value_field]
+				);
+
+				if ($comparison != 0) {
+					return $comparison;
+				}
+			}
+
+			return 0;
+		});
+	}
+
 	/**
 	 * Format graph items.
 	 *
