@@ -132,8 +132,8 @@ class CMenuHelper {
 				: null,
 			CWebUser::checkAccess(CRoleHelper::UI_REPORTS_AVAILABILITY_REPORT)
 				? (new CMenuItem(_('Availability report')))
-					->setUrl(new CUrl('report2.php'), 'report2.php')
-					->setAliases(['chart4.php'])
+					->setAction('availabilityreport.list')
+					->setAliases(['availabilityreport.trigger'])
 				: null,
 			CWebUser::checkAccess(CRoleHelper::UI_REPORTS_TOP_TRIGGERS)
 				? (new CMenuItem(_('Top 100 triggers')))->setAction('toptriggers.list')
@@ -162,11 +162,9 @@ class CMenuHelper {
 		$submenu_data_collection = [
 			CWebUser::checkAccess(CRoleHelper::UI_CONFIGURATION_TEMPLATE_GROUPS)
 				? (new CMenuItem(_('Template groups')))->setAction('templategroup.list')
-					->setAliases(['templategroup.edit'])
 				: null,
 			CWebUser::checkAccess(CRoleHelper::UI_CONFIGURATION_HOST_GROUPS)
 				? (new CMenuItem(_('Host groups')))->setAction('hostgroup.list')
-					->setAliases(['hostgroup.edit'])
 				: null,
 			CWebUser::checkAccess(CRoleHelper::UI_CONFIGURATION_TEMPLATES)
 				? (new CMenuItem(_('Templates')))
@@ -186,7 +184,7 @@ class CMenuHelper {
 						'item.list?context=host', 'trigger.list?context=host', 'graphs.php?context=host',
 						'host_discovery.php?context=host', 'item.prototype.list?context=host',
 						'trigger.prototype.list?context=host', 'host_prototypes.php?context=host',
-						'httpconf.php?context=host', 'host.edit'
+						'httpconf.php?context=host'
 					])
 				: null,
 			CWebUser::checkAccess(CRoleHelper::UI_CONFIGURATION_MAINTENANCE)
