@@ -1003,6 +1003,10 @@ class CMacrosResolverGeneral {
 							$value = date('H:i:s', $history[$itemid][0]['timestamp']);
 							break;
 
+						case 'ITEM.LOG.TIMESTAMP':
+							$value = $history[$itemid][0]['timestamp'];
+							break;
+
 						case 'ITEM.LOG.AGE':
 							$value = zbx_date2age($history[$itemid][0]['timestamp']);
 							break;
@@ -1256,21 +1260,31 @@ class CMacrosResolverGeneral {
 					case 'ITEM.LOG.DATE':
 						$value = date('Y.m.d', $history[$function['itemid']][0]['timestamp']);
 						break;
+
 					case 'ITEM.LOG.TIME':
 						$value = date('H:i:s', $history[$function['itemid']][0]['timestamp']);
 						break;
+
+					case 'ITEM.LOG.TIMESTAMP':
+						$value = $history[$function['itemid']][0]['timestamp'];
+						break;
+
 					case 'ITEM.LOG.AGE':
 						$value = zbx_date2age($history[$function['itemid']][0]['timestamp']);
 						break;
+
 					case 'ITEM.LOG.SOURCE':
 						$value = $history[$function['itemid']][0]['source'];
 						break;
+
 					case 'ITEM.LOG.SEVERITY':
 						$value = get_item_logtype_description($history[$function['itemid']][0]['severity']);
 						break;
+
 					case 'ITEM.LOG.NSEVERITY':
 						$value = $history[$function['itemid']][0]['severity'];
 						break;
+
 					case 'ITEM.LOG.EVENTID':
 						$value = $history[$function['itemid']][0]['logeventid'];
 						break;
@@ -2208,7 +2222,7 @@ class CMacrosResolverGeneral {
 		}
 
 		$db_interfaces = API::HostInterface()->get([
-			'output' => ['hostid', 'type', 'useip', 'ip', 'dns'],
+			'output' => ['hostid', 'type', 'useip', 'ip', 'dns', 'port'],
 			'hostids' => array_keys($hostids),
 			'filter' => ['main' => INTERFACE_PRIMARY]
 		]);
@@ -2232,7 +2246,9 @@ class CMacrosResolverGeneral {
 		}
 		unset($host_interface);
 
-		$interface_macros = ['IPADDRESS' => 'ip', 'HOST.IP' => 'ip', 'HOST.DNS' => 'dns', 'HOST.CONN' => 'conn'];
+		$interface_macros = ['IPADDRESS' => 'ip', 'HOST.IP' => 'ip', 'HOST.DNS' => 'dns', 'HOST.CONN' => 'conn',
+			'HOST.PORT' => 'port'
+		];
 
 		foreach ($macros as $triggerid => $macro_data) {
 			if (!array_key_exists($triggerid, $trigger_hosts_by_f_num)) {
@@ -2475,6 +2491,7 @@ class CMacrosResolverGeneral {
 			$hostids += array_flip($usermacros_data['hostids']);
 		}
 
+		$user_macro_parser_with_regex = new CUserMacroParser(['allow_regex' => true]);
 		$user_macro_parser = new CUserMacroParser();
 
 		/*
@@ -2504,14 +2521,14 @@ class CMacrosResolverGeneral {
 				]);
 
 				foreach ($db_host_macros as $db_host_macro) {
-					if ($user_macro_parser->parse($db_host_macro['macro']) != CParser::PARSE_SUCCESS) {
+					if ($user_macro_parser_with_regex->parse($db_host_macro['macro']) != CParser::PARSE_SUCCESS) {
 						continue;
 					}
 
 					$hostid = $db_host_macro['hostid'];
-					$macro = $user_macro_parser->getMacro();
-					$context = $user_macro_parser->getContext();
-					$regex = $user_macro_parser->getRegex();
+					$macro = $user_macro_parser_with_regex->getMacro();
+					$context = $user_macro_parser_with_regex->getContext();
+					$regex = $user_macro_parser_with_regex->getRegex();
 					$value = self::getMacroValue($db_host_macro);
 
 					if (!array_key_exists($hostid, $host_macros) || !array_key_exists($macro, $host_macros[$hostid])) {
@@ -2593,10 +2610,10 @@ class CMacrosResolverGeneral {
 			$global_macros = [];
 
 			foreach ($db_global_macros as $db_global_macro) {
-				if ($user_macro_parser->parse($db_global_macro['macro']) == CParser::PARSE_SUCCESS) {
-					$macro = $user_macro_parser->getMacro();
-					$context = $user_macro_parser->getContext();
-					$regex = $user_macro_parser->getRegex();
+				if ($user_macro_parser_with_regex->parse($db_global_macro['macro']) == CParser::PARSE_SUCCESS) {
+					$macro = $user_macro_parser_with_regex->getMacro();
+					$context = $user_macro_parser_with_regex->getContext();
+					$regex = $user_macro_parser_with_regex->getRegex();
 					$value = self::getMacroValue($db_global_macro);
 
 					if (!array_key_exists($macro, $global_macros)) {
