@@ -1,21 +1,16 @@
 <?php declare(strict_types = 0);
 /*
-** Zabbix
 ** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -45,9 +40,11 @@ class CRouter {
 	 */
 	private array $routes = [
 		// action									controller												layout					view
+		'acknowledge.edit'							=> ['CControllerAcknowledgeEdit',						'layout.json',			'acknowledge.edit'],
 		'action.create'								=> ['CControllerActionCreate',							'layout.json',			null],
 		'action.delete'								=> ['CControllerActionDelete',							'layout.json',			null],
 		'action.disable'							=> ['CControllerActionDisable',							'layout.json',			null],
+		'action.edit'								=> ['CControllerActionEdit',							'layout.json',			'action.edit'],
 		'action.enable'								=> ['CControllerActionEnable',							'layout.json',			null],
 		'action.list'								=> ['CControllerActionList',							'layout.htmlpage',		'action.list'],
 		'action.operation.check'					=> ['CControllerActionOperationCheck',					'layout.json',			null],
@@ -62,6 +59,8 @@ class CRouter {
 		'authentication.update'						=> ['CControllerAuthenticationUpdate',					null,					null],
 		'autoreg.edit'								=> ['CControllerAutoregEdit',							'layout.htmlpage',		'administration.autoreg.edit'],
 		'autoreg.update'							=> ['CControllerAutoregUpdate',							null,					null],
+		'availabilityreport.list'					=> ['CControllerAvailabilityReportList',				'layout.htmlpage',		'reports.availabilityreport.list'],
+		'availabilityreport.trigger'				=> ['CControllerAvailabilityReportTrigger',				'layout.htmlpage',		'reports.availabilityreport.trigger'],
 		'charts.view'								=> ['CControllerChartsView',							'layout.htmlpage',		'monitoring.charts.view'],
 		'charts.view.json'							=> ['CControllerChartsViewJson',						'layout.json',			'monitoring.charts.view.json'],
 		'connector.create'							=> ['CControllerConnectorCreate',						'layout.json',			null],
@@ -73,19 +72,21 @@ class CRouter {
 		'connector.update'							=> ['CControllerConnectorUpdate',						'layout.json',			null],
 		'copy.create'								=> ['CControllerCopyCreate',							'layout.json',			null],
 		'copy.edit'									=> ['CControllerCopyEdit',								'layout.json',			'copy.edit'],
-		'correlation.create'						=> ['CControllerCorrelationCreate',						null,					null],
-		'correlation.delete'						=> ['CControllerCorrelationDelete',						null,					null],
-		'correlation.disable'						=> ['CControllerCorrelationDisable',					null,					null],
-		'correlation.edit'							=> ['CControllerCorrelationEdit',						'layout.htmlpage',		'configuration.correlation.edit'],
-		'correlation.enable'						=> ['CControllerCorrelationEnable',						null,					null],
-		'correlation.list'							=> ['CControllerCorrelationList',						'layout.htmlpage',		'configuration.correlation.list'],
-		'correlation.update'						=> ['CControllerCorrelationUpdate',						null,					null],
+		'correlation.condition.check'				=> ['CControllerCorrelationConditionCheck',				'layout.json',			null],
+		'correlation.condition.edit'				=> ['CControllerCorrelationConditionEdit',				'layout.json',			'correlation.condition.edit'],
+		'correlation.create'						=> ['CControllerCorrelationCreate',						'layout.json',			null],
+		'correlation.delete'						=> ['CControllerCorrelationDelete',						'layout.json',			null],
+		'correlation.disable'						=> ['CControllerCorrelationDisable',					'layout.json',			null],
+		'correlation.edit'							=> ['CControllerCorrelationEdit',						'layout.json',			'correlation.edit'],
+		'correlation.enable'						=> ['CControllerCorrelationEnable',						'layout.json',			null],
+		'correlation.list'							=> ['CControllerCorrelationList',						'layout.htmlpage',		'correlation.list'],
+		'correlation.update'						=> ['CControllerCorrelationUpdate',						'layout.json',			null],
 		'dashboard.config.hash'						=> ['CControllerDashboardConfigHash',					'layout.json',			null],
 		'dashboard.delete'							=> ['CControllerDashboardDelete',						null,					null],
 		'dashboard.list'							=> ['CControllerDashboardList',							'layout.htmlpage',		'monitoring.dashboard.list'],
 		'dashboard.page.properties.check'			=> ['CControllerDashboardPagePropertiesCheck',			'layout.json',			null],
 		'dashboard.page.properties.edit'			=> ['CControllerDashboardPagePropertiesEdit',			'layout.json',			'dashboard.page.properties.edit'],
-		'dashboard.print'							=> ['CControllerDashboardPrint',						'layout.htmlpage',		'monitoring.dashboard.print'],
+		'dashboard.print'							=> ['CControllerDashboardPrint',						'layout.print',		    'monitoring.dashboard.print'],
 		'dashboard.properties.check'				=> ['CControllerDashboardPropertiesCheck',				'layout.json',			null],
 		'dashboard.properties.edit'					=> ['CControllerDashboardPropertiesEdit',				'layout.json',			'dashboard.properties.edit'],
 		'dashboard.share.update'					=> ['CControllerDashboardShareUpdate',					'layout.json',			null],
@@ -93,20 +94,21 @@ class CRouter {
 		'dashboard.view'							=> ['CControllerDashboardView',							'layout.htmlpage',		'monitoring.dashboard.view'],
 		'dashboard.widget.check'					=> ['CControllerDashboardWidgetCheck',					'layout.json',			null],
 		'dashboard.widget.rfrate'					=> ['CControllerDashboardWidgetRfRate',					'layout.json',			null],
-		'dashboard.widgets.sanitize'				=> ['CControllerDashboardWidgetsSanitize',				'layout.json',			null],
-		'discovery.create'							=> ['CControllerDiscoveryCreate',						null,					null],
-		'discovery.delete'							=> ['CControllerDiscoveryDelete',						null,					null],
-		'discovery.disable'							=> ['CControllerDiscoveryDisable',						null,					null],
-		'discovery.edit'							=> ['CControllerDiscoveryEdit',							'layout.htmlpage',		'configuration.discovery.edit'],
-		'discovery.enable'							=> ['CControllerDiscoveryEnable',						null,					null],
+		'dashboard.widgets.validate'				=> ['CControllerDashboardWidgetsValidate',				'layout.json',			null],
+		'discovery.check.check'						=> ['CControllerDiscoveryCheckCheck',					'layout.json',			null],
+		'discovery.check.edit'						=> ['CControllerDiscoveryCheckEdit',					'layout.json',			'discovery.check.edit'],
+		'discovery.create'							=> ['CControllerDiscoveryCreate',						'layout.json',			null],
+		'discovery.delete'							=> ['CControllerDiscoveryDelete',						'layout.json',			null],
+		'discovery.disable'							=> ['CControllerDiscoveryDisable',						'layout.json',			null],
+		'discovery.edit'							=> ['CControllerDiscoveryEdit',							'layout.json',			'configuration.discovery.edit'],
+		'discovery.enable'							=> ['CControllerDiscoveryEnable',						'layout.json',			null],
 		'discovery.list'							=> ['CControllerDiscoveryList',							'layout.htmlpage',		'configuration.discovery.list'],
-		'discovery.update'							=> ['CControllerDiscoveryUpdate',						null,					null],
+		'discovery.update'							=> ['CControllerDiscoveryUpdate',						'layout.json',			null],
 		'discovery.view'							=> ['CControllerDiscoveryView',							'layout.htmlpage',		'monitoring.discovery.view'],
 		'export.hosts'								=> ['CControllerExport',								'layout.export',		null],
 		'export.mediatypes'							=> ['CControllerExport',								'layout.export',		null],
 		'export.sysmaps'							=> ['CControllerExport',								'layout.export',		null],
 		'export.templates'							=> ['CControllerExport',								'layout.export',		null],
-		'export.valuemaps'							=> ['CControllerExport',								'layout.export',		null],
 		'favorite.create'							=> ['CControllerFavoriteCreate',						'layout.javascript',	null],
 		'favorite.delete'							=> ['CControllerFavoriteDelete',						'layout.javascript',	null],
 		'geomaps.edit'								=> ['CControllerGeomapsEdit',							'layout.htmlpage',		'administration.geomaps.edit'],
@@ -117,7 +119,9 @@ class CRouter {
 		'hintbox.eventlist'							=> ['CControllerHintboxEventlist',						'layout.json',			'hintbox.eventlist'],
 		'host.create'								=> ['CControllerHostCreate',							'layout.json',			null],
 		'host.dashboard.view'						=> ['CControllerHostDashboardView',						'layout.htmlpage',		'monitoring.host.dashboard.view'],
-		'host.edit'									=> ['CControllerHostEdit',								'layout.htmlpage',		'configuration.host.edit'],
+		'host.disable'								=> ['CControllerHostDisable',							'layout.json',			null],
+		'host.edit'									=> ['CControllerHostEdit',								'layout.json',			'host.edit'],
+		'host.enable'								=> ['CControllerHostEnable',							'layout.json',			null],
 		'host.list'									=> ['CControllerHostList',								'layout.htmlpage',		'configuration.host.list'],
 		'host.massdelete'							=> ['CControllerHostMassDelete',						'layout.json',			null],
 		'host.update'								=> ['CControllerHostUpdate',							'layout.json',			null],
@@ -126,7 +130,7 @@ class CRouter {
 		'hostgroup.create'							=> ['CControllerHostGroupCreate',						'layout.json',			null],
 		'hostgroup.delete'							=> ['CControllerHostGroupDelete',						'layout.json',			null],
 		'hostgroup.disable'							=> ['CControllerHostGroupDisable',						'layout.json',			null],
-		'hostgroup.edit'							=> ['CControllerHostGroupEdit',							'layout.htmlpage',		'configuration.hostgroup.edit'],
+		'hostgroup.edit'							=> ['CControllerHostGroupEdit',							'layout.json',			'hostgroup.edit'],
 		'hostgroup.enable'							=> ['CControllerHostGroupEnable',						'layout.json',			null],
 		'hostgroup.list'							=> ['CControllerHostGroupList',							'layout.htmlpage',		'configuration.hostgroup.list'],
 		'hostgroup.update'							=> ['CControllerHostGroupUpdate',						'layout.json',			null],
@@ -143,7 +147,25 @@ class CRouter {
 		'image.edit'								=> ['CControllerImageEdit',								'layout.htmlpage',		'administration.image.edit'],
 		'image.list'								=> ['CControllerImageList',								'layout.htmlpage',		'administration.image.list'],
 		'image.update'								=> ['CControllerImageUpdate',							null,					null],
-		'item.masscheck_now'						=> ['CControllerItemMassCheckNow',						'layout.json',			null],
+		'item.clear'								=> ['CControllerItemClear',								'layout.json',			null],
+		'item.create'								=> ['CControllerItemCreate',							'layout.json',			null],
+		'item.delete'								=> ['CControllerItemDelete',							'layout.json',			null],
+		'item.disable'								=> ['CControllerItemDisable',							'layout.json',			null],
+		'item.edit'									=> ['CControllerItemEdit',								'layout.json',			'item.edit'],
+		'item.enable'								=> ['CControllerItemEnable',							'layout.json',			null],
+		'item.execute'								=> ['CControllerItemExecuteNow',						'layout.json',			null],
+		'item.list'									=> ['CControllerItemList',								'layout.htmlpage',		'item.list'],
+		'item.massupdate'							=> ['CControllerItemMassupdate',						'layout.json',			'item.massupdate'],
+		'item.update'								=> ['CControllerItemUpdate',							'layout.json',			null],
+		'item.prototype.create'						=> ['CControllerItemPrototypeCreate',					'layout.json',			null],
+		'item.prototype.delete'						=> ['CControllerItemPrototypeDelete',					'layout.json',			null],
+		'item.prototype.disable'					=> ['CControllerItemPrototypeDisable',					'layout.json',			null],
+		'item.prototype.edit'						=> ['CControllerItemPrototypeEdit',						'layout.json',			'item.prototype.edit'],
+		'item.prototype.enable'						=> ['CControllerItemPrototypeEnable',					'layout.json',			null],
+		'item.prototype.list'						=> ['CControllerItemPrototypeList',						'layout.htmlpage',		'item.prototype.list'],
+		'item.prototype.massupdate'					=> ['CControllerItemMassupdate',						'layout.json',			'item.massupdate'],
+		'item.prototype.update'						=> ['CControllerItemPrototypeUpdate',					'layout.json',			null],
+		'item.tags.list'							=> ['CControllerItemTagsList',							'layout.json',			'item.tags.list'],
 		'latest.view'								=> ['CControllerLatestView',							'layout.htmlpage',		'monitoring.latest.view'],
 		'latest.view.refresh'						=> ['CControllerLatestViewRefresh',						'layout.json',			'monitoring.latest.view.refresh'],
 		'macros.edit'								=> ['CControllerMacrosEdit',							'layout.htmlpage',		'administration.macros.edit'],
@@ -156,41 +178,41 @@ class CRouter {
 		'maintenance.timeperiod.check'				=> ['CControllerMaintenanceTimePeriodCheck',			'layout.json',			null],
 		'maintenance.update'						=> ['CControllerMaintenanceUpdate',						'layout.json',			null],
 		'map.view'									=> ['CControllerMapView',								'layout.htmlpage',		'monitoring.map.view'],
-		'mediatype.create'							=> ['CControllerMediatypeCreate',						null,					null],
-		'mediatype.delete'							=> ['CControllerMediatypeDelete',						null,					null],
-		'mediatype.disable'							=> ['CControllerMediatypeDisable',						null,					null],
-		'mediatype.edit'							=> ['CControllerMediatypeEdit',							'layout.htmlpage',		'administration.mediatype.edit'],
-		'mediatype.enable'							=> ['CControllerMediatypeEnable',						null,					null],
-		'mediatype.list'							=> ['CControllerMediatypeList',							'layout.htmlpage',		'administration.mediatype.list'],
-		'mediatype.update'							=> ['CControllerMediatypeUpdate',						null,					null],
+		'mediatype.create'							=> ['CControllerMediatypeCreate',						'layout.json',			null],
+		'mediatype.delete'							=> ['CControllerMediatypeDelete',						'layout.json',			null],
+		'mediatype.disable'							=> ['CControllerMediatypeDisable',						'layout.json',			null],
+		'mediatype.edit'							=> ['CControllerMediatypeEdit',							'layout.json',			'mediatype.edit'],
+		'mediatype.enable'							=> ['CControllerMediatypeEnable',						'layout.json',			null],
+		'mediatype.list'							=> ['CControllerMediatypeList',							'layout.htmlpage',		'mediatype.list'],
+		'mediatype.message.check'					=> ['CControllerMediatypeMessageCheck',					'layout.json',			null],
+		'mediatype.message.edit'					=> ['CControllerMediatypeMessageEdit',					'layout.json',			'mediatype.message.edit'],
+		'mediatype.test.edit'						=> ['CControllerMediatypeTestEdit',						'layout.json',			'mediatype.test.edit'],
+		'mediatype.test.send'						=> ['CControllerMediatypeTestSend',						'layout.json',			null],
+		'mediatype.update'							=> ['CControllerMediatypeUpdate',						'layout.json',			null],
 		'menu.popup'								=> ['CControllerMenuPopup',								'layout.json',			null],
+		'mfa.edit'									=> ['CControllerMfaEdit',								'layout.json',			'mfa.edit'],
+		'mfa.check'									=> ['CControllerMfaCheck',								'layout.json',			null],
 		'miscconfig.edit'							=> ['CControllerMiscConfigEdit',						'layout.htmlpage',		'administration.miscconfig.edit'],
 		'miscconfig.update'							=> ['CControllerMiscConfigUpdate',						null,					null],
-		'module.disable'							=> ['CControllerModuleUpdate',							null,					null],
-		'module.edit'								=> ['CControllerModuleEdit',							'layout.htmlpage',		'administration.module.edit'],
-		'module.enable'								=> ['CControllerModuleUpdate',							null,					null],
-		'module.list'								=> ['CControllerModuleList',							'layout.htmlpage',		'administration.module.list'],
+		'module.disable'							=> ['CControllerModuleDisable',							'layout.json',			null],
+		'module.edit'								=> ['CControllerModuleEdit',							'layout.json',			'module.edit'],
+		'module.enable'								=> ['CControllerModuleEnable',							'layout.json',			null],
+		'module.list'								=> ['CControllerModuleList',							'layout.htmlpage',		'module.list'],
 		'module.scan'								=> ['CControllerModuleScan',							null,					null],
-		'module.update'								=> ['CControllerModuleUpdate',							null,					null],
+		'module.update'								=> ['CControllerModuleUpdate',							'layout.json',			null],
 		'notifications.get'							=> ['CControllerNotificationsGet',						'layout.json',			null],
 		'notifications.mute'						=> ['CControllerNotificationsMute',						'layout.json',			null],
 		'notifications.read'						=> ['CControllerNotificationsRead',						'layout.json',			null],
+		'notifications.snooze'						=> ['CControllerNotificationsSnooze',					'layout.json',			null],
 		'popup'										=> ['CControllerPopup',									'layout.htmlpage',		'popup.view'],
 		'popup.acknowledge.create'					=> ['CControllerPopupAcknowledgeCreate',				'layout.json',			null],
-		'popup.acknowledge.edit'					=> ['CControllerPopupAcknowledgeEdit',					'layout.json',			'popup.acknowledge.edit'],
-		'popup.action.edit'							=> ['CControllerPopupActionEdit',						'layout.json',			'popup.action.edit'],
 		'popup.action.operation.edit'				=> ['CControllerPopupActionOperationEdit',				'layout.json',			'popup.operation.edit'],
 		'popup.action.operations.list'				=> ['CControllerPopupActionOperationsList',				'layout.json',			'popup.action.operations.list'],
 		'popup.condition.check'						=> ['CControllerActionConditionCheck',					'layout.json',			null],
 		'popup.condition.edit'						=> ['CControllerPopupActionConditionEdit',				'layout.json',			'popup.condition.edit'],
-		'popup.condition.event.corr'				=> ['CControllerPopupConditionEventCorr',				'layout.json',			'popup.condition.edit'],
 		'popup.condition.operations'				=> ['CControllerPopupConditionOperations',				'layout.json',			'popup.condition.edit'],
 		'popup.dashboard.share.edit'				=> ['CControllerPopupDashboardShareEdit',				'layout.json',			'popup.dashboard.share.edit'],
-		'popup.discovery.check'						=> ['CControllerPopupDiscoveryCheck',					'layout.json',			'popup.discovery.check'],
 		'popup.generic'								=> ['CControllerPopupGeneric',							'layout.json',			'popup.generic'],
-		'popup.host.edit'							=> ['CControllerHostEdit',								'layout.json',			'popup.host.edit'],
-		'popup.hostgroup.edit'						=> ['CControllerHostGroupEdit',							'layout.json',			'popup.hostgroup.edit'],
-		'popup.httpstep'							=> ['CControllerPopupHttpStep',							'layout.json',			'popup.httpstep'],
 		'popup.import'								=> ['CControllerPopupImport',							'layout.json',			'popup.import'],
 		'popup.import.compare'						=> ['CControllerPopupImportCompare',					'layout.json',			'popup.import.compare'],
 		'popup.itemtest.edit'						=> ['CControllerPopupItemTestEdit',						'layout.json',			'popup.itemtestedit.view'],
@@ -203,19 +225,10 @@ class CRouter {
 		'popup.lldoperation'						=> ['CControllerPopupLldOperation',						'layout.json',			'popup.lldoperation'],
 		'popup.lldoverride'							=> ['CControllerPopupLldOverride',						'layout.json',			'popup.lldoverride'],
 		'popup.massupdate.host'						=> ['CControllerPopupMassupdateHost',					'layout.json',			'popup.massupdate.host'],
-		'popup.massupdate.item'						=> ['CControllerPopupMassupdateItem',					'layout.json',			'popup.massupdate.item'],
-		'popup.massupdate.itemprototype'			=> ['CControllerPopupMassupdateItem',					'layout.json',			'popup.massupdate.item'],
 		'popup.massupdate.service'					=> ['CControllerPopupMassupdateService',				'layout.json',			'popup.massupdate.service'],
-		'popup.massupdate.template'					=> ['CControllerPopupMassupdateTemplate',				'layout.json',			'popup.massupdate.template'],
-		'popup.massupdate.trigger'					=> ['CControllerPopupMassupdateTrigger',				'layout.json',			'popup.massupdate.trigger'],
-		'popup.massupdate.triggerprototype'			=> ['CControllerPopupMassupdateTrigger',				'layout.json',			'popup.massupdate.trigger'],
 		'popup.media'								=> ['CControllerPopupMedia',							'layout.json',			'popup.media'],
-		'popup.mediatype.message'					=> ['CControllerPopupMediatypeMessage',					'layout.json',			'popup.mediatype.message'],
 		'popup.mediatypemapping.check'				=> ['CControllerPopupMediaTypeMappingCheck',			'layout.json',			null],
 		'popup.mediatypemapping.edit'				=> ['CControllerPopupMediaTypeMappingEdit',				'layout.json',			'popup.mediatypemapping.edit'],
-		'popup.mediatypetest.edit'					=> ['CControllerPopupMediatypeTestEdit',				'layout.json',			'popup.mediatypetest.edit'],
-		'popup.mediatypetest.send'					=> ['CControllerPopupMediatypeTestSend',				'layout.json',			null],
-		'popup.proxy.edit'							=> ['CControllerPopupProxyEdit',						'layout.json',			'popup.proxy.edit'],
 		'popup.usergroupmapping.check'				=> ['CControllerPopupUserGroupMappingCheck',			'layout.json',			null],
 		'popup.usergroupmapping.edit'				=> ['CControllerPopupUserGroupMappingEdit',				'layout.json',			'popup.usergroupmapping.edit'],
 		'popup.scheduledreport.create'				=> ['CControllerPopupScheduledReportCreate',			'layout.json',			null],
@@ -224,17 +237,13 @@ class CRouter {
 		'popup.scheduledreport.subscription.edit'	=> ['CControllerPopupScheduledReportSubscriptionEdit',	'layout.json',			'popup.scheduledreport.subscription'],
 		'popup.scheduledreport.test'				=> ['CControllerPopupScheduledReportTest',				'layout.json',			'popup.scheduledreport.test'],
 		'popup.scriptexec'							=> ['CControllerPopupScriptExec',						'layout.json',			'popup.scriptexec'],
-		'popup.service.edit'						=> ['CControllerPopupServiceEdit',						'layout.json',			'popup.service.edit'],
 		'popup.service.statusrule.edit'				=> ['CControllerPopupServiceStatusRuleEdit',			'layout.json',			'popup.service.statusrule.edit'],
 		'popup.services'							=> ['CControllerPopupServices',							'layout.json',			'popup.services'],
-		'popup.sla.edit'							=> ['CControllerPopupSlaEdit',							'layout.json',			'popup.sla.edit'],
 		'popup.sla.excludeddowntime.edit'			=> ['CControllerPopupSlaExcludedDowntimeEdit',			'layout.json',			'popup.sla.excludeddowntime.edit'],
 		'popup.tabfilter.delete'					=> ['CControllerPopupTabFilterDelete',					'layout.json',			null],
 		'popup.tabfilter.edit'						=> ['CControllerPopupTabFilterEdit',					'layout.json',			'popup.tabfilter.edit'],
 		'popup.tabfilter.update'					=> ['CControllerPopupTabFilterUpdate',					'layout.json',			null],
-		'popup.templategroup.edit'					=> ['CControllerTemplateGroupEdit',						'layout.json',			'popup.templategroup.edit'],
 		'popup.testtriggerexpr'						=> ['CControllerPopupTestTriggerExpr',					'layout.json',			'popup.testtriggerexpr'],
-		'popup.token.edit'							=> ['CControllerPopupTokenEdit',						'layout.json',			'popup.token.edit'],
 		'popup.token.view'							=> ['CControllerPopupTokenView',						'layout.json',			'popup.token.view'],
 		'popup.triggerexpr'							=> ['CControllerPopupTriggerExpr',						'layout.json',			'popup.triggerexpr'],
 		'popup.valuemap.edit'						=> ['CControllerPopupValueMapEdit',						'layout.json',			'popup.valuemap.edit'],
@@ -246,10 +255,16 @@ class CRouter {
 		'proxy.config.refresh'						=> ['CControllerProxyConfigRefresh',					'layout.json',			null],
 		'proxy.create'								=> ['CControllerProxyCreate',							'layout.json',			null],
 		'proxy.delete'								=> ['CControllerProxyDelete',							'layout.json',			null],
+		'proxy.edit'								=> ['CControllerProxyEdit',								'layout.json',			'proxy.edit'],
 		'proxy.host.disable'						=> ['CControllerProxyHostDisable',						'layout.json',			null],
 		'proxy.host.enable'							=> ['CControllerProxyHostEnable',						'layout.json',			null],
 		'proxy.list'								=> ['CControllerProxyList',								'layout.htmlpage',		'administration.proxy.list'],
 		'proxy.update'								=> ['CControllerProxyUpdate',							'layout.json',			null],
+		'proxygroup.create'							=> ['CControllerProxyGroupCreate',						'layout.json',			null],
+		'proxygroup.delete'							=> ['CControllerProxyGroupDelete',						'layout.json',			null],
+		'proxygroup.edit'							=> ['CControllerProxyGroupEdit',						'layout.json',			'proxygroup.edit'],
+		'proxygroup.list'							=> ['CControllerProxyGroupList',						'layout.htmlpage',		'administration.proxygroup.list'],
+		'proxygroup.update'							=> ['CControllerProxyGroupUpdate',						'layout.json',			null],
 		'queue.details'								=> ['CControllerQueueDetails',							'layout.htmlpage',		'administration.queue.details'],
 		'queue.overview'							=> ['CControllerQueueOverview',							'layout.htmlpage',		'administration.queue.overview'],
 		'queue.overview.proxy'						=> ['CControllerQueueOverviewProxy',					'layout.htmlpage',		'administration.queue.overview.proxy'],
@@ -267,14 +282,17 @@ class CRouter {
 		'scheduledreport.enable'					=> ['CControllerScheduledReportEnable',					null,					null],
 		'scheduledreport.list'						=> ['CControllerScheduledReportList',					'layout.htmlpage',		'reports.scheduledreport.list'],
 		'scheduledreport.update'					=> ['CControllerScheduledReportUpdate',					null,					null],
-		'script.create'								=> ['CControllerScriptCreate',							null,					null],
-		'script.delete'								=> ['CControllerScriptDelete',							null,					null],
-		'script.edit'								=> ['CControllerScriptEdit',							'layout.htmlpage',		'administration.script.edit'],
+		'script.create'								=> ['CControllerScriptCreate',							'layout.json',			null],
+		'script.delete'								=> ['CControllerScriptDelete',							'layout.json',			null],
+		'script.edit'								=> ['CControllerScriptEdit',							'layout.json',			'administration.script.edit'],
 		'script.list'								=> ['CControllerScriptList',							'layout.htmlpage',		'administration.script.list'],
-		'script.update'								=> ['CControllerScriptUpdate',							null,					null],
+		'script.update'								=> ['CControllerScriptUpdate',							'layout.json',			null],
+		'script.userinput.edit'						=> ['CControllerScriptUserInputEdit',					'layout.json',			'script.userinput.edit'],
+		'script.userinput.check'					=> ['CControllerScriptUserInputCheck',					'layout.json',			null],
 		'search'									=> ['CControllerSearch',								'layout.htmlpage',		'search'],
 		'service.create'							=> ['CControllerServiceCreate',							'layout.json',			null],
 		'service.delete'							=> ['CControllerServiceDelete',							'layout.json',			null],
+		'service.edit'								=> ['CControllerServiceEdit',							'layout.json',			'service.edit'],
 		'service.list'								=> ['CControllerServiceList',							'layout.htmlpage',		'service.list'],
 		'service.list.edit'							=> ['CControllerServiceListEdit',						'layout.htmlpage',		'service.list.edit'],
 		'service.list.edit.refresh'					=> ['CControllerServiceListEditRefresh',				'layout.json',			'service.list.edit.refresh'],
@@ -284,31 +302,62 @@ class CRouter {
 		'sla.create'								=> ['CControllerSlaCreate',								'layout.json',			null],
 		'sla.delete'								=> ['CControllerSlaDelete',								'layout.json',			null],
 		'sla.disable'								=> ['CControllerSlaDisable',							'layout.json',			null],
+		'sla.edit'									=> ['CControllerSlaEdit',								'layout.json',			'sla.edit'],
 		'sla.enable'								=> ['CControllerSlaEnable',								'layout.json',			null],
 		'sla.excludeddowntime.validate'				=> ['CControllerSlaExcludedDowntimeValidate',			'layout.json',			null],
 		'sla.list'									=> ['CControllerSlaList',								'layout.htmlpage',		'sla.list'],
 		'sla.update'								=> ['CControllerSlaUpdate',								'layout.json',			null],
 		'slareport.list'							=> ['CControllerSlaReportList',							'layout.htmlpage',		'slareport.list'],
+		'softwareversioncheck.get'					=> ['CControllerSoftwareVersionCheckGet',				'layout.json',			null],
+		'softwareversioncheck.update'				=> ['CControllerSoftwareVersionCheckUpdate',			'layout.json',			null],
 		'system.warning'							=> ['CControllerSystemWarning',							'layout.warning',		'system.warning'],
 		'tabfilter.profile.update'					=> ['CControllerTabFilterProfileUpdate',				'layout.json',			null],
+		'template.create'							=> ['CControllerTemplateCreate',						'layout.json',			null],
 		'template.dashboard.delete'					=> ['CControllerTemplateDashboardDelete',				null,					null],
 		'template.dashboard.edit'					=> ['CControllerTemplateDashboardEdit',					'layout.htmlpage',		'configuration.dashboard.edit'],
 		'template.dashboard.list'					=> ['CControllerTemplateDashboardList',					'layout.htmlpage',		'configuration.dashboard.list'],
 		'template.dashboard.update'					=> ['CControllerTemplateDashboardUpdate',				'layout.json',			null],
+		'template.delete'							=> ['CControllerTemplateDelete',						'layout.json',			null],
+		'template.edit'								=> ['CControllerTemplateEdit',							'layout.json',			'template.edit'],
+		'template.list'								=> ['CControllerTemplateList',							'layout.htmlpage',		'template.list'],
+		'template.massupdate'						=> ['CControllerTemplateMassupdate',					'layout.json',			'template.massupdate'],
+		'template.update'							=> ['CControllerTemplateUpdate',						'layout.json',			null],
 		'templategroup.create'						=> ['CControllerTemplateGroupCreate',					'layout.json',			null],
 		'templategroup.delete'						=> ['CControllerTemplateGroupDelete',					'layout.json',			null],
-		'templategroup.edit'						=> ['CControllerTemplateGroupEdit',						'layout.htmlpage',		'configuration.templategroup.edit'],
+		'templategroup.edit'						=> ['CControllerTemplateGroupEdit',						'layout.json',			'templategroup.edit'],
 		'templategroup.list'						=> ['CControllerTemplateGroupList',						'layout.htmlpage',		'configuration.templategroup.list'],
 		'templategroup.update'						=> ['CControllerTemplateGroupUpdate',					'layout.json',			null],
+		'timeouts.edit'								=> ['CControllerTimeoutsEdit',							'layout.htmlpage',		'administration.timeouts.edit'],
+		'timeouts.update'							=> ['CControllerTimeoutsUpdate',						null,					null],
+		'timeselector.calc'							=> ['CControllerTimeSelectorCalc',						'layout.json',			null],
 		'timeselector.update'						=> ['CControllerTimeSelectorUpdate',					'layout.json',			null],
 		'token.create'								=> ['CControllerTokenCreate',							'layout.json',			null],
 		'token.delete'								=> ['CControllerTokenDelete',							'layout.json',			null],
 		'token.disable'								=> ['CControllerTokenDisable',							null,					null],
+		'token.edit'								=> ['CControllerTokenEdit',								'layout.json',			'token.edit'],
 		'token.enable'								=> ['CControllerTokenEnable',							null,					null],
 		'token.list'								=> ['CControllerTokenList',								'layout.htmlpage',		'administration.token.list'],
 		'token.update'								=> ['CControllerTokenUpdate',							'layout.json',			null],
+		'toptriggers.list'							=> ['CControllerTopTriggersList',						'layout.htmlpage',		'reports.toptriggers.list'],
 		'trigdisplay.edit'							=> ['CControllerTrigDisplayEdit',						'layout.htmlpage',		'administration.trigdisplay.edit'],
 		'trigdisplay.update'						=> ['CControllerTrigDisplayUpdate',						null,					null],
+		'trigger.create'							=> ['CControllerTriggerCreate',							'layout.json',			null],
+		'trigger.delete'							=> ['CControllerTriggerDelete',							'layout.json',			null],
+		'trigger.disable'							=> ['CControllerTriggerDisable',						'layout.json',			null],
+		'trigger.edit'								=> ['CControllerTriggerEdit',							'layout.json',			'trigger.edit'],
+		'trigger.enable'							=> ['CControllerTriggerEnable',							'layout.json',			null],
+		'trigger.expression.constructor'			=> ['CControllerTriggerExpressionConstructor',			'layout.json',			'trigger.expression.constructor'],
+		'trigger.list'								=> ['CControllerTriggerList',							'layout.htmlpage',		'trigger.list'],
+		'trigger.massupdate'						=> ['CControllerTriggerMassupdate',						'layout.json',			'trigger.massupdate'],
+		'trigger.prototype.create'					=> ['CControllerTriggerPrototypeCreate',				'layout.json',			null],
+		'trigger.prototype.delete'					=> ['CControllerTriggerPrototypeDelete',				'layout.json',			null],
+		'trigger.prototype.disable'					=> ['CControllerTriggerPrototypeDisable',				'layout.json',			null],
+		'trigger.prototype.edit'					=> ['CControllerTriggerPrototypeEdit',					'layout.json',			'trigger.prototype.edit'],
+		'trigger.prototype.enable'					=> ['CControllerTriggerPrototypeEnable',				'layout.json',			null],
+		'trigger.prototype.list'					=> ['CControllerTriggerPrototypeList',					'layout.htmlpage',		'trigger.prototype.list'],
+		'trigger.prototype.massupdate'				=> ['CControllerTriggerMassupdate',						'layout.json',			'trigger.massupdate'],
+		'trigger.prototype.update'					=> ['CControllerTriggerPrototypeUpdate',				'layout.json',			null],
+		'trigger.update'							=> ['CControllerTriggerUpdate',							'layout.json',			null],
 		'user.create'								=> ['CControllerUserCreate',							null,					null],
 		'user.delete'								=> ['CControllerUserDelete',							null,					null],
 		'user.edit'									=> ['CControllerUserEdit',								'layout.htmlpage',		'administration.user.edit'],
@@ -317,14 +366,15 @@ class CRouter {
 		'user.unblock'								=> ['CControllerUserUnblock',							null,					null],
 		'user.update'								=> ['CControllerUserUpdate',							null,					null],
 		'user.provision'							=> ['CControllerUserProvision',							null,					null],
+		'user.reset.totp'							=> ['CControllerUserResetTotp',							null,					null],
 		'usergroup.create'							=> ['CControllerUsergroupCreate',						null,					null],
 		'usergroup.delete'							=> ['CControllerUsergroupDelete',						null,					null],
-		'usergroup.edit'							=> ['CControllerUsergroupEdit',							'layout.htmlpage',		'administration.usergroup.edit'],
-		'usergroup.groupright.add'					=> ['CControllerUsergroupGrouprightAdd',				'layout.json',			'administration.usergroup.grouprights'],
-		'usergroup.templategroupright.add'			=> ['CControllerUsergroupTemplateGrouprightAdd',		'layout.json',			'administration.usergroup.templategrouprights'],
-		'usergroup.list'							=> ['CControllerUsergroupList',							'layout.htmlpage',		'administration.usergroup.list'],
+		'usergroup.edit'							=> ['CControllerUsergroupEdit',							'layout.htmlpage',		'usergroup.edit'],
+		'usergroup.list'							=> ['CControllerUsergroupList',							'layout.htmlpage',		'usergroup.list'],
 		'usergroup.massupdate'						=> ['CControllerUsergroupMassUpdate',					null,					null],
-		'usergroup.tagfilter.add'					=> ['CControllerUsergroupTagfilterAdd',					'layout.json',			'administration.usergroup.tagfilters'],
+		'usergroup.tagfilter.edit'					=> ['CControllerUsergroupTagFilterEdit',				'layout.json',			'usergroup.tagfilter.edit'],
+		'usergroup.tagfilter.check'					=> ['CControllerUsergroupTagFilterCheck',				'layout.json',			null],
+		'usergroup.tagfilter.list'					=> ['CControllerUsergroupTagFilterList',				'layout.json',			'usergroup.tagfilter.list'],
 		'usergroup.update'							=> ['CControllerUsergroupUpdate',						null,					null],
 		'userprofile.edit'							=> ['CControllerUserProfileEdit',						'layout.htmlpage',		'administration.user.edit'],
 		'userprofile.update'						=> ['CControllerUserProfileUpdate',						null,					null],
@@ -334,6 +384,9 @@ class CRouter {
 		'userrole.list'								=> ['CControllerUserroleList',							'layout.htmlpage',		'administration.userrole.list'],
 		'userrole.update'							=> ['CControllerUserroleUpdate',						null,					null],
 		'web.view'									=> ['CControllerWebView',								'layout.htmlpage',		'monitoring.web.view'],
+		'webscenario.step.check'					=> ['CControllerWebScenarioStepCheck',					'layout.json',			null],
+		'webscenario.step.edit'						=> ['CControllerWebScenarioStepEdit',					'layout.json',			'webscenario.step.edit'],
+		'widget.navigation.tree.toggle'				=> ['CControllerWidgetNavigationTreeToggle',			'layout.json',			null],
 
 		// legacy actions
 		'auditacts.php'					=> ['CLegacyAction', null, null],
@@ -344,7 +397,6 @@ class CRouter {
 		'chart4.php'					=> ['CLegacyAction', null, null],
 		'chart6.php'					=> ['CLegacyAction', null, null],
 		'chart7.php'					=> ['CLegacyAction', null, null],
-		'disc_prototypes.php'			=> ['CLegacyAction', null, null],
 		'graphs.php'					=> ['CLegacyAction', null, null],
 		'history.php'					=> ['CLegacyAction', null, null],
 		'host_discovery.php'			=> ['CLegacyAction', null, null],
@@ -357,19 +409,14 @@ class CRouter {
 		'imgstore.php'					=> ['CLegacyAction', null, null],
 		'index.php'						=> ['CLegacyAction', null, null],
 		'index_http.php'				=> ['CLegacyAction', null, null],
+		'index_mfa.php'					=> ['CLegacyAction', null, null],
 		'index_sso.php'					=> ['CLegacyAction', null, null],
-		'items.php'						=> ['CLegacyAction', null, null],
 		'jsrpc.php'						=> ['CLegacyAction', null, null],
 		'map.php'						=> ['CLegacyAction', null, null],
-		'report2.php'					=> ['CLegacyAction', null, null],
 		'report4.php'					=> ['CLegacyAction', null, null],
 		'sysmap.php'					=> ['CLegacyAction', null, null],
 		'sysmaps.php'					=> ['CLegacyAction', null, null],
-		'templates.php' 				=> ['CLegacyAction', null, null],
-		'toptriggers.php'				=> ['CLegacyAction', null, null],
-		'tr_events.php'					=> ['CLegacyAction', null, null],
-		'trigger_prototypes.php'		=> ['CLegacyAction', null, null],
-		'triggers.php'					=> ['CLegacyAction', null, null]
+		'tr_events.php'					=> ['CLegacyAction', null, null]
 	];
 
 	private const DASHBOARD_ACTIONS = [
