@@ -1,21 +1,16 @@
-<?php declare(strict_types = 1);
+<?php declare(strict_types = 0);
 /*
-** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -48,23 +43,29 @@ class CExpressionParser extends CParser {
 	 * An options array.
 	 *
 	 * Supported options:
-	 *   'lldmacros' => false             Enable low-level discovery macros usage in trigger expression.
+	 *   'usermacros' => false            Enable user macros usage in expression.
+	 *   'lldmacros' => false             Enable low-level discovery macros usage in expression.
 	 *   'collapsed_expression' => false  Short trigger expression.
 	 *                                       For example: {439} > {$MAX_THRESHOLD} or {439} < {$MIN_THRESHOLD}
 	 *   'calculated' => false            Parse calculated item formula instead of trigger expression.
 	 *   'host_macro' => false            Allow {HOST.HOST} macro as host name part in the query.
 	 *   'host_macro_n' => false          Allow {HOST.HOST} and {HOST.HOST<1-9>} macros as host name part in the query.
 	 *   'empty_host' => false            Allow empty hostname in the query string.
+	 *   'escape_backslashes' => true     Disable backslash escaping in history function parameters prior to v7.0.
+	 *   'macros_n' => []                 Array of strings having supported reference macros.
 	 *
 	 * @var array
 	 */
 	private $options = [
+		'usermacros' => false,
 		'lldmacros' => false,
 		'collapsed_expression' => false,
 		'calculated' => false,
 		'host_macro' => false,
 		'host_macro_n' => false,
-		'empty_host' => false
+		'empty_host' => false,
+		'escape_backslashes' => true,
+		'macros_n' => []
 	];
 
 	/**
@@ -523,15 +524,15 @@ class CExpressionParser extends CParser {
 	/**
 	 * Parses a constant in the expression.
 	 *
-	 * The constant can be:
+	 * The constant can be (depending on options):
 	 *  - function like func(<expression>)
 	 *  - function like func(/host/item,<params>)
 	 *  - floating point number; can be with suffix [KMGTsmhdw]
 	 *  - string
-	 *  - macro like {TRIGGER.VALUE}
-	 *  - user macro like {$MACRO}
-	 *  - LLD macro like {#LLD}
-	 *  - LLD macro with function like {{#LLD}.func())}
+	 *  - macros like {TRIGGER.VALUE} and {{TRIGGER.VALUE}.func()}
+	 *  - user macros like {$MACRO} and {{$MACRO}.func()}
+	 *  - LLD macros like {#LLD} and {{#LLD}.func()}
+	 *  - macros like {FUNCTION.VALUE}, {FUNCTION.RECOVERY.VALUE9}
 	 *
 	 * @param string  $source
 	 * @param int     $pos
@@ -542,26 +543,41 @@ class CExpressionParser extends CParser {
 	 * @return bool  Returns true if parsed successfully, false otherwise.
 	 */
 	private static function parseConstant(string $source, int &$pos, array &$tokens, array $options, int $depth): bool {
-		$user_macro_parser = new CUserMacroParser();
-
-		if (self::parseNumber($source, $pos, $tokens) || self::parseString($source, $pos, $tokens)
-				|| self::parseUsing($user_macro_parser, $source, $pos, $tokens,
-					CExpressionParserResult::TOKEN_TYPE_USER_MACRO)) {
+		if (self::parseNumber($source, $pos, $tokens) || self::parseString($source, $pos, $tokens)) {
 			return true;
 		}
 
 		if (!$options['calculated']) {
-			$macro_parser = new CMacroParser(['macros' => ['{TRIGGER.VALUE}']]);
+			if (self::parseUsing(new CMacroParser(['macros' => ['{TRIGGER.VALUE}']]), $source, $pos, $tokens,
+					CExpressionParserResult::TOKEN_TYPE_MACRO)) {
+				return true;
+			}
 
-			if (self::parseUsing($macro_parser, $source, $pos, $tokens, CExpressionParserResult::TOKEN_TYPE_MACRO)) {
+			if (self::parseUsing(new CMacroFunctionParser(['macros' => ['{TRIGGER.VALUE}']]), $source, $pos, $tokens,
+					CExpressionParserResult::TOKEN_TYPE_MACRO)) {
+				return true;
+			}
+		}
+
+		if ($options['macros_n']) {
+			$_options = [
+				'macros' => $options['macros_n'],
+				'ref_type' => CMacroParser::REFERENCE_NUMERIC
+			];
+
+			if (self::parseUsing(new CMacroParser($_options), $source, $pos, $tokens,
+					CExpressionParserResult::TOKEN_TYPE_MACRO)) {
+				return true;
+			}
+
+			if (self::parseUsing(new CMacroFunctionParser($_options), $source, $pos, $tokens,
+					CExpressionParserResult::TOKEN_TYPE_MACRO)) {
 				return true;
 			}
 		}
 
 		if ($options['collapsed_expression']) {
-			$functionid_parser = new CFunctionIdParser();
-
-			if (self::parseUsing($functionid_parser, $source, $pos, $tokens,
+			if (self::parseUsing(new CFunctionIdParser, $source, $pos, $tokens,
 					CExpressionParserResult::TOKEN_TYPE_FUNCTIONID_MACRO)) {
 				return true;
 			}
@@ -574,17 +590,25 @@ class CExpressionParser extends CParser {
 			return true;
 		}
 
-		if ($options['lldmacros']) {
-			$lld_macro_parser = new CLLDMacroParser();
+		if ($options['usermacros']) {
+			if (self::parseUsing(new CUserMacroParser, $source, $pos, $tokens,
+					CExpressionParserResult::TOKEN_TYPE_USER_MACRO)) {
+				return true;
+			}
 
-			if (self::parseUsing($lld_macro_parser, $source, $pos, $tokens,
+			if (self::parseUsing(new CUserMacroFunctionParser, $source, $pos, $tokens,
+					CExpressionParserResult::TOKEN_TYPE_USER_MACRO)) {
+				return true;
+			}
+		}
+
+		if ($options['lldmacros']) {
+			if (self::parseUsing(new CLLDMacroParser, $source, $pos, $tokens,
 					CExpressionParserResult::TOKEN_TYPE_LLD_MACRO)) {
 				return true;
 			}
 
-			$lld_macro_function_parser = new CLLDMacroFunctionParser();
-
-			if (self::parseUsing($lld_macro_function_parser, $source, $pos, $tokens,
+			if (self::parseUsing(new CLLDMacroFunctionParser, $source, $pos, $tokens,
 					CExpressionParserResult::TOKEN_TYPE_LLD_MACRO)) {
 				return true;
 			}
@@ -605,12 +629,13 @@ class CExpressionParser extends CParser {
 	 */
 	private static function parseHistFunction(string $source, int &$pos, array &$tokens, array $options): bool {
 		$hist_function_parser = new CHistFunctionParser([
-			'usermacros' => true,
+			'usermacros' => $options['usermacros'],
 			'lldmacros' => $options['lldmacros'],
 			'calculated' => $options['calculated'],
 			'host_macro' => $options['host_macro'],
 			'host_macro_n' => $options['host_macro_n'],
-			'empty_host' => $options['empty_host']
+			'empty_host' => $options['empty_host'],
+			'escape_backslashes' => $options['escape_backslashes']
 		]);
 
 		if ($hist_function_parser->parse($source, $pos) == CParser::PARSE_FAIL) {
@@ -648,7 +673,7 @@ class CExpressionParser extends CParser {
 			int $depth): bool {
 		$p = $pos;
 
-		if (!preg_match('/^([a-z0-9]+)\(/', substr($source, $p), $matches)) {
+		if (!preg_match('/^([a-z0-9_]+)\(/', substr($source, $p), $matches)) {
 			return false;
 		}
 
@@ -751,7 +776,11 @@ class CExpressionParser extends CParser {
 	 * @return bool returns true if parsed successfully, false otherwise
 	 */
 	private static function parseNumber(string $source, int &$pos, array &$tokens): bool {
-		$number_parser = new CNumberParser(['with_minus' => false, 'with_suffix' => true]);
+		$number_parser = new CNumberParser([
+			'with_minus' => false,
+			'with_size_suffix' => true,
+			'with_time_suffix' => true
+		]);
 
 		if ($number_parser->parse($source, $pos) == CParser::PARSE_FAIL) {
 			return false;
@@ -823,22 +852,20 @@ class CExpressionParser extends CParser {
 	 */
 	public static function quoteString(string $value, bool $allow_macros = true, bool $force = false): string {
 		if (!$force) {
-			$number_parser = new CNumberParser(['with_suffix' => true]);
+			$number_parser = new CNumberParser(['with_size_suffix' => true, 'with_time_suffix' => true]);
 
 			if ($number_parser->parse($value) == CParser::PARSE_SUCCESS) {
 				return $value;
 			}
 
 			if ($allow_macros) {
-				$user_macro_parser = new CUserMacroParser();
-				$macro_parser = new CMacroParser(['macros' => ['{TRIGGER.VALUE}']]);
-				$lld_macro_parser = new CLLDMacroParser();
-				$lld_macro_function_parser = new CLLDMacroFunctionParser;
-
-				if ($user_macro_parser->parse($value) == CParser::PARSE_SUCCESS
-						|| $macro_parser->parse($value) == CParser::PARSE_SUCCESS
-						|| $lld_macro_parser->parse($value) == CParser::PARSE_SUCCESS
-						|| $lld_macro_function_parser->parse($value) == CParser::PARSE_SUCCESS) {
+				$parser_options = ['macros' => ['{TRIGGER.VALUE}']];
+				if ((new CMacroParser($parser_options))->parse($value) == CParser::PARSE_SUCCESS
+						|| (new CMacroFunctionParser($parser_options))->parse($value) == CParser::PARSE_SUCCESS
+						|| (new CUserMacroParser)->parse($value) == CParser::PARSE_SUCCESS
+						|| (new CUserMacroFunctionParser)->parse($value) == CParser::PARSE_SUCCESS
+						|| (new CLLDMacroParser)->parse($value) == CParser::PARSE_SUCCESS
+						|| (new CLLDMacroFunctionParser)->parse($value) == CParser::PARSE_SUCCESS) {
 					return $value;
 				}
 			}
