@@ -1,21 +1,16 @@
 <?php
 /*
-** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 class CUrlFactory {
@@ -29,13 +24,6 @@ class CUrlFactory {
 	 * @var array
 	 */
 	protected static $contextConfigs = [
-		'actionconf.php' => [
-			'remove' => ['actionid']
-		],
-		'disc_prototypes.php' => [
-			'remove' => ['itemid'],
-			'add' => ['hostid', 'parent_discoveryid']
-		],
 		'graphs.php' => [
 			'remove' => ['graphid'],
 			'add' => ['hostid', 'parent_discoveryid']
@@ -51,26 +39,9 @@ class CUrlFactory {
 		'httpconf.php' => [
 			'remove' => ['httptestid']
 		],
-		'items.php' => [
-			'remove' => ['itemid']
-		],
-		'maintenance.php' => [
-			'remove' => ['maintenanceid']
-		],
 		'sysmaps.php' => [
 			'remove' => ['sysmapid']
 		],
-		'templates.php' => [
-			'remove' => ['templateid']
-		],
-		'trigger_prototypes.php' => [
-			'remove' =>  ['triggerid'],
-			'add' => ['parent_discoveryid', 'hostid']
-		],
-		'triggers.php' => [
-			'remove' => ['triggerid'],
-			'add' => ['hostid']
-		],
 		'__default' => [
 			'remove' => ['cancel', 'form', 'delete']
 		]
