@@ -1,21 +1,16 @@
 <?php
 /*
-** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -27,7 +22,10 @@ try {
 catch (DBException $e) {
 	echo (new CView('general.warning', [
 		'header' => 'Database error',
-		'messages' => [$e->getMessage()],
+		'messages' => [CWebUser::getType() == USER_TYPE_SUPER_ADMIN && $e->getCode() != DB::INIT_ERROR
+			? _('System error occurred. Please contact Zabbix administrator.')
+			: $e->getMessage()
+		],
 		'theme' => ZBX_DEFAULT_THEME
 	]))->getOutput();
 
@@ -70,7 +68,7 @@ catch (Exception $e) {
 
 CProfiler::getInstance()->start();
 
-global $ZBX_SERVER, $ZBX_SERVER_PORT, $page;
+global $page;
 
 $page = [
 	'title' => null,
