@@ -1,21 +1,16 @@
 <?php
 /*
-** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -25,14 +20,13 @@
 ?>
 
 <script type="text/x-jquery-tmpl" id="tmpl-item-row-<?= GRAPH_TYPE_NORMAL ?>">
-	<tr id="items_#{number}" class="sortable">
+	<tr id="items_#{number}" class="graph-item">
 		<!-- icon + hidden -->
 		<?php if ($readonly): ?>
 			<td>
 		<?php else: ?>
 			<td class="<?= ZBX_STYLE_TD_DRAG_ICON ?>">
 				<div class="<?= ZBX_STYLE_DRAG_ICON ?>"></div>
-				<span class="ui-icon ui-icon-arrowthick-2-n-s move"></span>
 		<?php endif ?>
 			<input type="hidden" id="items_#{number}_gitemid" name="items[#{number}][gitemid]" value="#{gitemid}">
 			<input type="hidden" id="items_#{number}_itemid" name="items[#{number}][itemid]" value="#{itemid}">
@@ -46,7 +40,7 @@
 
 		<!-- row number -->
 		<td>
-			<span id="items_#{number}_number" class="items_number">#{number_nr}:</span>
+			<span class="<?= ZBX_STYLE_LIST_NUMBERED_ITEM ?>">:</span>
 		</td>
 
 		<!-- name -->
@@ -68,6 +62,7 @@
 						CALC_FNC_AVG => _('avg'),
 						CALC_FNC_MAX => _('max')
 					]))
+					->setReadonly($readonly)
 			?>
 		</td>
 
@@ -76,6 +71,7 @@
 			<?= (new CSelect('items[#{number}][drawtype]'))
 					->setValue('#{drawtype}')
 					->addOptions(CSelect::createOptionsFromArray($graph_item_drawtypes))
+					->setReadonly($readonly)
 			?>
 		</td>
 
@@ -87,6 +83,7 @@
 						GRAPH_YAXIS_SIDE_LEFT => _('Left'),
 						GRAPH_YAXIS_SIDE_RIGHT => _('Right')
 					]))
+					->setReadonly($readonly)
 			?>
 		</td>
 
@@ -105,14 +102,13 @@
 </script>
 
 <script type="text/x-jquery-tmpl" id="tmpl-item-row-<?= GRAPH_TYPE_STACKED ?>">
-	<tr id="items_#{number}" class="sortable">
+	<tr id="items_#{number}" class="graph-item">
 		<!-- icon + hidden -->
 		<?php if ($readonly): ?>
 			<td>
 		<?php else: ?>
 			<td class="<?= ZBX_STYLE_TD_DRAG_ICON ?>">
 				<div class="<?= ZBX_STYLE_DRAG_ICON ?>"></div>
-				<span class="ui-icon ui-icon-arrowthick-2-n-s move"></span>
 		<?php endif ?>
 			<input type="hidden" id="items_#{number}_gitemid" name="items[#{number}][gitemid]" value="#{gitemid}">
 			<input type="hidden" id="items_#{number}_itemid" name="items[#{number}][itemid]" value="#{itemid}">
@@ -126,7 +122,7 @@
 
 		<!-- row number -->
 		<td>
-			<span id="items_#{number}_number" class="items_number">#{number_nr}:</span>
+			<span class="<?= ZBX_STYLE_LIST_NUMBERED_ITEM ?>">:</span>
 		</td>
 
 		<!-- name -->
@@ -147,6 +143,7 @@
 						CALC_FNC_AVG => _('avg'),
 						CALC_FNC_MAX => _('max')
 					]))
+					->setReadonly($readonly)
 			?>
 		</td>
 
@@ -158,6 +155,7 @@
 						GRAPH_YAXIS_SIDE_LEFT => _('Left'),
 						GRAPH_YAXIS_SIDE_RIGHT => _('Right')
 					]))
+					->setReadonly($readonly)
 			?>
 		</td>
 
@@ -176,14 +174,13 @@
 </script>
 
 <script type="text/x-jquery-tmpl" id="tmpl-item-row-<?= GRAPH_TYPE_PIE ?>">
-	<tr id="items_#{number}" class="sortable">
+	<tr id="items_#{number}" class="graph-item">
 		<!-- icon + hidden -->
 		<?php if ($readonly): ?>
 			<td>
 		<?php else: ?>
 			<td class="<?= ZBX_STYLE_TD_DRAG_ICON ?>">
 				<div class="<?= ZBX_STYLE_DRAG_ICON ?>"></div>
-				<span class="ui-icon ui-icon-arrowthick-2-n-s move"></span>
 		<?php endif ?>
 			<input type="hidden" id="items_#{number}_gitemid" name="items[#{number}][gitemid]" value="#{gitemid}">
 			<input type="hidden" id="items_#{number}_itemid" name="items[#{number}][itemid]" value="#{itemid}">
@@ -197,7 +194,7 @@
 
 		<!-- row number -->
 		<td>
-			<span id="items_#{number}_number" class="items_number">#{number_nr}:</span>
+			<span class="<?= ZBX_STYLE_LIST_NUMBERED_ITEM ?>">:</span>
 		</td>
 
 		<!-- name -->
@@ -217,6 +214,7 @@
 						GRAPH_ITEM_SIMPLE =>_('Simple'),
 						GRAPH_ITEM_SUM =>_('Graph sum')
 					]))
+					->setReadonly($readonly)
 			?>
 		</td>
 
@@ -230,6 +228,7 @@
 						CALC_FNC_MAX => _('max'),
 						CALC_FNC_LST => _('last')
 					]))
+					->setReadonly($readonly)
 			?>
 		</td>
 
@@ -248,14 +247,13 @@
 </script>
 
 <script type="text/x-jquery-tmpl" id="tmpl-item-row-<?= GRAPH_TYPE_EXPLODED ?>">
-	<tr id="items_#{number}" class="sortable">
+	<tr id="items_#{number}" class="graph-item">
 		<!-- icon + hidden -->
 		<?php if ($readonly): ?>
 			<td>
 		<?php else: ?>
 			<td class="<?= ZBX_STYLE_TD_DRAG_ICON ?>">
 				<div class="<?= ZBX_STYLE_DRAG_ICON ?>"></div>
-				<span class="ui-icon ui-icon-arrowthick-2-n-s move"></span>
 		<?php endif ?>
 			<input type="hidden" id="items_#{number}_gitemid" name="items[#{number}][gitemid]" value="#{gitemid}">
 			<input type="hidden" id="items_#{number}_itemid" name="items[#{number}][itemid]" value="#{itemid}">
@@ -269,7 +267,7 @@
 
 		<!-- row number -->
 		<td>
-			<span id="items_#{number}_number" class="items_number">#{number_nr}:</span>
+			<span class="<?= ZBX_STYLE_LIST_NUMBERED_ITEM ?>">:</span>
 		</td>
 
 		<!-- name -->
@@ -289,6 +287,7 @@
 						GRAPH_ITEM_SIMPLE => _('Simple'),
 						GRAPH_ITEM_SUM => _('Graph sum')
 					]))
+					->setReadonly($readonly)
 			?>
 		</td>
 
@@ -302,6 +301,7 @@
 						CALC_FNC_MAX => _('max'),
 						CALC_FNC_LST => _('last')
 					]))
+					->setReadonly($readonly)
 			?>
 		</td>
 
@@ -323,15 +323,18 @@
 	const view = {
 		form_name: null,
 		graphs: null,
+		context: null,
+		parent_discoveryid: null,
 
-		init({form_name, theme_colors, graphs, items}) {
+		init({form_name, theme_colors, graphs, items, context, parent_discoveryid}) {
 			this.form_name = form_name;
 			colorPalette.setThemeColors(theme_colors);
 			this.graphs = graphs;
+			this.context = context;
+			this.is_discovery = parent_discoveryid !== null;
 
 			items.forEach((item, i) => {
 				item.number = i;
-				item.number_nr = i + 1;
 				item.name = item.host + '<?= NAME_DELIMITER ?>' + item.name;
 
 				this.loadItem(item);
@@ -354,6 +357,7 @@
 					src.setArgument('height', $('#height').val());
 					src.setArgument('graphtype', $('#graphtype').val());
 					src.setArgument('legend', $('#show_legend').is(':checked') ? 1 : 0);
+					src.setArgument('resolve_macros', this.context === 'template' ? 0 : 1);
 
 					if (this.graphs.graphtype == <?= GRAPH_TYPE_PIE ?>
 							|| this.graphs.graphtype == <?= GRAPH_TYPE_EXPLODED ?>) {
@@ -390,7 +394,7 @@
 						src.setArgument('showtriggers', $('#show_triggers').is(':checked') ? 1 : 0);
 					}
 
-					$('#itemsTable tr.sortable').each((i, node) => {
+					$('#itemsTable tbody tr.graph-item').each((i, node) => {
 						const short_fmt = [];
 
 						$(node).find('*[name]').each((_, input) => {
@@ -423,14 +427,15 @@
 			});
 
 			if (this.graphs.readonly) {
-				$('#itemsTable').sortable({disabled: true}).find('input').prop('readonly', true);
-				$('z-select', '#itemsTable').prop('disabled', true);
-
-				const size = $('#itemsTable tr.sortable').length;
+				const size = $('#itemsTable tbody tr.graph-item').length;
 
 				for (let i = 0; i < size; i++) {
-					$('#items_' + i + '_color').removeAttr('onchange');
-					$('#lbl_items_' + i + '_color').removeAttr('onclick');
+					$('#items_' + i + '_color')
+						.removeAttr('onchange')
+						.prop('readonly', true);
+					$('#lbl_items_' + i + '_color')
+						.removeAttr('onclick')
+						.prop('readonly', true);
 				}
 			}
 
@@ -480,7 +485,16 @@
 				$('form[name="' + view.form_name + '"]').submit();
 			});
 
-			!this.graphs.readonly && this.initSortable();
+			new CSortable(document.querySelector('#itemsTable tbody'), {
+				selector_handle: 'div.<?= ZBX_STYLE_DRAG_ICON ?>',
+				freeze_end: 1,
+				enable_sorting: !this.graphs.readonly
+			})
+				.on(CSortable.EVENT_SORT, this.recalculateSortOrder);
+
+			!this.graphs.readonly && this.rewriteNameLinks();
+
+			this.setSubmitCallback();
 		},
 
 		loadItem(item) {
@@ -513,10 +527,9 @@
 					}
 				}
 
-				const number = $('#itemsTable tr.sortable').length;
+				const number = $('#itemsTable tbody tr.graph-item').length;
 				const item = {
 					number: number,
-					number_nr: number + 1,
 					gitemid: null,
 					itemid: list.values[i].itemid,
 					calc_fnc: null,
@@ -534,10 +547,7 @@
 				$(`#items_${number}_color`).colorpicker();
 			}
 
-			if (!this.graphs.readonly) {
-				this.activateSortable();
-				this.rewriteNameLinks();
-			}
+			!this.graphs.readonly && this.rewriteNameLinks();
 		},
 
 		getOnlyHostParam() {
@@ -547,7 +557,7 @@
 		},
 
 		rewriteNameLinks() {
-			const size = $('#itemsTable tr.sortable').length;
+			const size = $('#itemsTable tbody tr.graph-item').length;
 
 			for (let i = 0; i < size; i++) {
 				const parameters = {
@@ -592,61 +602,41 @@
 			$('#items_' + number).remove();
 
 			this.recalculateSortOrder();
-			!this.graphs.readonly && this.activateSortable();
 		},
 
 		recalculateSortOrder() {
 			let i = 0;
 
 			// Rewrite IDs, set "tmp" prefix.
-			$('#itemsTable tr.sortable').find('*[id]').each(function() {
+			$('#itemsTable tbody tr.graph-item').find('*[id]').each(function() {
 				const $obj = $(this);
 
 				$obj.attr('id', 'tmp' + $obj.attr('id'));
 			});
 
-			$('#itemsTable tr.sortable').each(function() {
+			$('#itemsTable tbody tr.graph-item').each(function() {
 				const $obj = $(this);
 
 				$obj.attr('id', 'tmp' + $obj.attr('id'));
 			});
 
-			// Rewrite IDs to new order.
-			$('#itemsTable tr.sortable').each(function() {
-				const $obj = $(this);
+			for (const [index, row] of document.querySelectorAll('#itemsTable tbody tr.graph-item').entries()) {
+				row.id = row.id.substring(3).replace(/\d+/, `${index}`);
 
-				// Rewrite IDs in input fields.
-				$obj.find('*[id]').each(function() {
-					const $obj = $(this);
-					const id = $obj.attr('id').substring(3);
-					const part1 = id.substring(0, id.indexOf('items_') + 5);
-					let part2 = id.substring(id.indexOf('items_') + 6);
+				row.querySelectorAll('[id]').forEach(element => {
+					element.id = element.id.substring(3).replace(/\d+/, `${index}`);
 
-					part2 = part2.substring(part2.indexOf('_') + 1);
-
-					$obj.attr('id', part1 + '_' + i + '_' + part2);
-
-					// Set sortorder.
-					if (part2 === 'sortorder') {
-						$obj.val(i);
+					if (element.id.includes('sortorder')) {
+						element.value = index;
 					}
 				});
 
-				// Rewrite IDs in <tr>.
-				const id = $obj.attr('id').substring(3);
-				const part1 = id.substring(0, id.indexOf('items_') + 5);
-
-				$obj.attr('id', part1 + '_' + i);
-
-				i++;
-			});
-
-			i = 0;
-
-			$('#itemsTable tr.sortable').each(function() {
-				// Set row number.
-				$('.items_number', this).text((i + 1) + ':');
+				row.querySelectorAll('[name]').forEach(element => {
+					element.name = element.name.replace(/\d+/, `${index}`);
+				});
+			}
 
+			$('#itemsTable tbody tr.graph-item').each(function() {
 				// Set remove number.
 				$('#items_' + i + '_remove').data('remove', i);
 
@@ -656,61 +646,6 @@
 			!view.graphs.readonly && view.rewriteNameLinks();
 		},
 
-		initSortable() {
-			$('#itemsTable').sortable({
-				disabled: ($('#itemsTable tr.sortable').length < 2),
-				items: 'tbody tr.sortable',
-				axis: 'y',
-				containment: 'parent',
-				cursor: 'grabbing',
-				handle: 'div.<?= ZBX_STYLE_DRAG_ICON ?>',
-				tolerance: 'pointer',
-				opacity: 0.6,
-				update: this.recalculateSortOrder,
-				helper: (e, ui) => {
-					for (const td of ui.find('>td')) {
-						const $td = $(td);
-						$td.attr('width', $td.width())
-					}
-
-					return ui;
-				},
-				stop: (e, ui) => {
-					ui.item.find('>td').removeAttr('width');
-				},
-				start: (e, ui) => {
-					$(ui.placeholder).height($(ui.helper).height());
-				}
-			});
-		},
-
-		activateSortable() {
-			$('#itemsTable').sortable({disabled: ($('#itemsTable tr.sortable').length < 2)});
-		},
-
-		editHost(e, hostid) {
-			e.preventDefault();
-			const host_data = {hostid};
-
-			this.openHostPopup(host_data);
-		},
-
-		openHostPopup(host_data) {
-			const original_url = location.href;
-			const overlay = PopUp('popup.host.edit', host_data, {
-				dialogueid: 'host_edit',
-				dialogue_class: 'modal-popup-large',
-				prevent_navigation: true
-			});
-
-			overlay.$dialogue[0].addEventListener('dialogue.create', this.events.hostSuccess, {once: true});
-			overlay.$dialogue[0].addEventListener('dialogue.update', this.events.hostSuccess, {once: true});
-			overlay.$dialogue[0].addEventListener('dialogue.delete', this.events.hostDelete, {once: true});
-			overlay.$dialogue[0].addEventListener('overlay.close', () => {
-				history.replaceState({}, '', original_url);
-			}, {once: true});
-		},
-
 		refresh() {
 			const url = new Curl('');
 			const form = document.getElementsByName(this.form_name)[0];
@@ -719,37 +654,29 @@
 			post(url.getUrl(), fields);
 		},
 
-		events: {
-			hostSuccess(e) {
-				const data = e.detail;
+		setSubmitCallback() {
+			window.popupManagerInstance.setSubmitCallback((e) => {
+				let curl = null;
 
-				if ('success' in data) {
-					postMessageOk(data.success.title);
+				if ('success' in e.detail) {
+					postMessageOk(e.detail.success.title);
 
-					if ('messages' in data.success) {
-						postMessageDetails('success', data.success.messages);
+					if ('messages' in e.detail.success) {
+						postMessageDetails('success', e.detail.success.messages);
+					}
+
+					if ('action' in e.detail.success && e.detail.success.action === 'delete') {
+						curl = this.is_discovery ? new Curl('host_discovery.php') : new Curl('graphs.php');
+						curl.setArgument('context', this.context);
 					}
 				}
-
-				view.refresh();
-			},
-
-			hostDelete(e) {
-				const data = e.detail;
-
-				if ('success' in data) {
-					postMessageOk(data.success.title);
-
-					if ('messages' in data.success) {
-						postMessageDetails('success', data.success.messages);
-					}
+				if (curl) {
+					location.href = curl.getUrl();
 				}
-
-				const curl = new Curl('zabbix.php');
-				curl.setArgument('action', 'host.list');
-
-				location.href = curl.getUrl();
-			}
+				else {
+					view.refresh();
+				}
+			});
 		}
 	};
 </script>
