@@ -141,15 +141,15 @@
 				var $obj = $(this),
 					ms = $obj.data('multiSelect');
 
-				if (ms.options.disabled === true) {
-					$obj.removeAttr('aria-disabled');
-					$('.multiselect-list', $obj).removeClass('disabled');
-					$('.multiselect-button', $obj.parent()).prop('disabled', false);
-					$('.multiselect-optional-select-button', $obj.parent()).prop('disabled', false);
-					$('input', $obj).prop('disabled', false);
-					$obj.append(makeMultiSelectInput($obj));
+				$obj.removeAttr('aria-disabled');
+				$('.multiselect-list', $obj).removeClass('disabled');
+				$('.multiselect-button', $obj.parent()).prop('disabled', false);
+				$('.multiselect-optional-select-button', $obj.parent()).prop('disabled', false);
+				$('input', $obj).prop('disabled', false);
 
+				if (ms.options.disabled === true) {
 					ms.options.disabled = false;
+					$obj.append(makeMultiSelectInput($obj));
 
 					cleanSearch($obj);
 				}
@@ -166,15 +166,15 @@
 				var $obj = $(this),
 					ms = $obj.data('multiSelect');
 
-				if (ms.options.disabled === false) {
-					$obj.attr('aria-disabled', true);
-					$('.multiselect-list', $obj).addClass('disabled');
-					$('.multiselect-button', $obj.parent()).prop('disabled', true);
-					$('.multiselect-optional-select-button', $obj.parent()).prop('disabled', true);
-					$('input[type="text"]', $obj).remove();
-					$('input', $obj).prop('disabled', true);
+				$obj.attr('aria-disabled', true);
+				$('.multiselect-list', $obj).addClass('disabled');
+				$('.multiselect-button', $obj.parent()).prop('disabled', true);
+				$('.multiselect-optional-select-button', $obj.parent()).prop('disabled', true);
+				$('input', $obj).prop('disabled', true);
 
+				if (ms.options.disabled === false) {
 					ms.options.disabled = true;
+					$('input[type="text"]', $obj).remove();
 
 					cleanSearch($obj);
 				}
@@ -311,19 +311,11 @@
 		setDisabledEntries: function(entries) {
 			this.each(function() {
 				const $obj = $(this);
-				const ms_parameters = $obj.data('multiSelect');
+				const ms = $obj.data('multiSelect');
 
-				if (typeof ms_parameters === 'undefined') {
-					return;
+				if (ms?.options.popup.parameters !== undefined) {
+					ms.options.popup.parameters.disableids = entries;
 				}
-
-				const link = new Curl(ms_parameters.options.url);
-				link.setArgument('disabledids', entries);
-
-				ms_parameters.options.url = link.getUrl();
-				ms_parameters.options.popup.parameters.disableids = entries;
-
-				$obj.data('multiSelect', ms_parameters);
 			});
 		},
 
@@ -396,9 +388,9 @@
 	 *     bool   data[][inaccessible]  (optional)
 	 *     bool   data[][disabled]      (optional)
 	 *     string placeholder           set custom placeholder (optional)
-	 *     array  excludeids            the list of excluded ids (optional)
 	 *     string defaultValue          default value for input element (optional)
-	 *     bool   disabled              turn on/off readonly state (optional)
+	 *     bool   disabled              turn on/off disabled state (optional)
+	 *     bool   readonly              turn on/off readonly state (optional)
 	 *     bool   hidden                hide element (optional)
 	 *     bool   addNew                allow user to create new names (optional)
 	 *     int    selectedLimit         how many items can be selected (optional)
@@ -443,7 +435,6 @@
 			},
 			placeholder: t('type here to search'),
 			data: [],
-			excludeids: [],
 			addNew: false,
 			defaultValue: null,
 			custom_select: false,
@@ -451,6 +442,7 @@
 			suggest_list_modifier: null,
 			custom_suggest_select_handler: null,
 			disabled: false,
+			readonly: false,
 			selectedLimit: 0,
 			limit: 20,
 			popup: {},
@@ -516,9 +508,15 @@
 
 			$obj.append($selected_div.append($selected_ul));
 
-			if (ms.options.disabled) {
-				$obj.attr('aria-disabled', true);
-				$selected_ul.addClass('disabled');
+			if (ms.options.disabled || ms.options.readonly) {
+				if (ms.options.disabled) {
+					$obj.attr('aria-disabled', true);
+					$selected_ul.addClass('disabled');
+				}
+				else {
+					$obj.attr('aria-readonly', true);
+					$selected_ul.attr('aria-readonly', true);
+				}
 			}
 			else {
 				$obj.append(makeMultiSelectInput($obj));
@@ -526,7 +524,7 @@
 
 			$obj
 				.on('mousedown', function(event) {
-					if (isSearchFieldVisible($obj) && ms.options.selectedLimit != 1) {
+					if (isSearchFieldVisible($obj) && ms.options.selectedLimit != 1 && !ms.options.readonly) {
 						$obj.addClass('active');
 						$('.selected li.selected', $obj).removeClass('selected');
 
@@ -562,7 +560,7 @@
 					ms.select_button.on('click', (e) => openSelectPopup($obj, e.target));
 				}
 
-				if (ms.options.disabled) {
+				if (ms.options.disabled || ms.options.readonly) {
 					ms.select_button.prop('disabled', true);
 				}
 
@@ -688,7 +686,9 @@
 									cache: false,
 									data: jQuery.extend({
 										search: search,
-										limit: getLimit($obj),
+										limit: ms.options.limit !== 0
+											? ms.options.limit + getSkipSearchIds($obj).length + 1
+											: undefined
 									}, preselect_values)
 								})
 									.then(function(response) {
@@ -994,7 +994,7 @@
 						.append($('<span>')
 							.addClass([ZBX_STYLE_BTN_ICON, ZBX_ICON_REMOVE_SMALLER])
 							.on('click', function() {
-								if (!ms.options.disabled && !item_disabled) {
+								if (!ms.options.disabled && !item_disabled && !ms.options.readonly) {
 									removeSelected($obj, item.id);
 									if (isSearchFieldVisible($obj)) {
 										$('input[type="text"]', $obj)[0].focus({preventScroll:true});
@@ -1006,7 +1006,7 @@
 						)
 				)
 				.on('click', function() {
-					if (isSearchFieldVisible($obj) && ms.options.selectedLimit != 1) {
+					if (isSearchFieldVisible($obj) && ms.options.selectedLimit != 1 && !ms.options.readonly) {
 						$('.selected li.selected', $obj).removeClass('selected');
 						$(this).addClass('selected');
 
@@ -1155,6 +1155,8 @@
 			}
 		}
 
+		const skip_search_ids = getSkipSearchIds($obj);
+
 		let available_more = false;
 
 		if (ms.options.custom_suggest_list !== null) {
@@ -1163,8 +1165,7 @@
 		else {
 			$.each(data, function(i, item) {
 				if (ms.options.limit == 0 || ms.values.available.size < ms.options.limit) {
-					if (!ms.values.available.has(item.id) && ms.values.selected[item.id] === undefined
-						&& !ms.options.excludeids.includes(item.id)) {
+					if (!skip_search_ids.includes(item.id)) {
 						ms.values.available.set(item.id, item);
 					}
 				}
@@ -1458,11 +1459,13 @@
 		return !$obj.hasClass('search-disabled');
 	}
 
-	function getLimit($obj) {
-		var ms = $obj.data('multiSelect');
+	function getSkipSearchIds($obj) {
+		const ms = $obj.data('multiSelect');
 
-		return (ms.options.limit != 0)
-			? ms.options.limit + objectSize(ms.values.selected) + ms.options.excludeids.length + 1
-			: null;
+		return [...new Set([
+			...Object.keys(ms.values.selected),
+			...(ms.options.popup.parameters?.excludeids || []),
+			...(ms.options.popup.parameters?.disableids || [])
+		])];
 	}
 })(jQuery);
