@@ -37,6 +37,12 @@ class Widget extends CWidget {
 	public const UNITS_POSITION_AFTER = 2;
 	public const UNITS_POSITION_BELOW = 3;
 
+	// Predefined colors for thresholds. Each next threshold takes the next sequential value from the palette.
+	public const DEFAULT_COLOR_PALETTE = [
+		'E65660', 'FCCB1D', '3BC97D', '2ED3B7', '19D0D7', '29C2FA', '58B0FE', '5D98FE', '859AFA', 'E580FA',
+		'F773C7', 'FC5F7E', 'FC738E', 'FF6D2E', 'F48D48', 'F89C3A', 'FBB318', 'FECF62', '87CE40', 'A3E86D'
+	];
+
 	public function getDefaultName(): string {
 		return _('Gauge');
 	}
@@ -44,8 +50,8 @@ class Widget extends CWidget {
 	public function getTranslationStrings(): array {
 		return [
 			'class.widget.js' => [
-				'Actions' => _s('Actions'),
-				'Download image' => _s('Download image')
+				'Actions' => _('Actions'),
+				'Download image' => _('Download image')
 			]
 		];
 	}
