@@ -1,21 +1,16 @@
 <?php declare(strict_types = 0);
 /*
-** Zabbix
 ** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -28,7 +23,7 @@
 
 use Widgets\Item\Widget;
 
-if ($data['error'] !== '') {
+if (array_key_exists('error', $data)) {
 	$body = (new CTableInfo())->setNoDataMessage($data['error']);
 }
 else {
@@ -45,6 +40,16 @@ else {
 
 	$rows = [];
 
+	if ($data['sparkline']) {
+		$rows[] = (new CSparkline())
+			->setColor('#'.$data['sparkline']['color'])
+			->setLineWidth($data['sparkline']['width'])
+			->setFill($data['sparkline']['fill'])
+			->setValue($data['sparkline']['value'])
+			->setTimePeriodFrom($data['sparkline']['from'])
+			->setTimePeriodTo($data['sparkline']['to']);
+	}
+
 	foreach ($classes_vertical as $row_key => $row_class) {
 		$cols = [];
 
@@ -81,17 +86,10 @@ else {
 					break;
 
 				case 'item_value':
-					$div->addClass('item-value');
-
-					if (array_key_exists('value_type', $cell_data)) {
-						$div->addClass(($cell_data['value_type'] == ITEM_VALUE_TYPE_FLOAT
-								|| $cell_data['value_type'] == ITEM_VALUE_TYPE_UINT64)
-							? 'type-number'
-							: 'type-text'
-						);
-					}
-
-					$div->addItem(drawValueCell($cell_data));
+					$div
+						->addClass('item-value')
+						->addClass($cell_data['is_numeric'] ? 'type-number' : 'type-text')
+						->addItem(drawValueCell($cell_data));
 					break;
 			}
 
@@ -101,9 +99,7 @@ else {
 		$rows[] = new CDiv($cols);
 	}
 
-	$body = new CDiv(
-		new CLink($rows, $data['url'])
-	);
+	$body = new CLink($rows, $data['url']);
 
 	if ($data['bg_color'] !== '') {
 		$body->addStyle('background-color: #'.$data['bg_color'].';');
@@ -112,6 +108,7 @@ else {
 
 (new CWidgetView($data))
 	->addItem($body)
+	->setVar('info', $data['info'])
 	->show();
 
 /**
@@ -141,18 +138,16 @@ function drawValueCell(array $cell_data): array {
 		$item_content_div->addItem($units_div);
 	}
 
-	if (array_key_exists('value', $cell_data['parts'])) {
-		$item_value_div = (new CDiv())->addClass('value');
+	$item_value_div = (new CDiv())->addClass('value');
 
-		if ($cell_data['parts']['value']['text'] === null) {
-			$cell_data['parts']['value']['text'] = _('No data');
-			$item_value_div->addClass('item-value-no-data');
-		}
-
-		$item_value_div = addTextFormatting($item_value_div, $cell_data['parts']['value']);
-		$item_content_div->addItem($item_value_div);
+	if ($cell_data['parts']['value']['text'] === null) {
+		$cell_data['parts']['value']['text'] = _('No data');
+		$item_value_div->addClass('item-value-no-data');
 	}
 
+	$item_value_div = addTextFormatting($item_value_div, $cell_data['parts']['value']);
+	$item_content_div->addItem($item_value_div);
+
 	if (array_key_exists('decimals', $cell_data['parts'])) {
 		$item_decimals_div = (new CDiv())->addClass('decimals');
 		$item_decimals_div = addTextFormatting($item_decimals_div, $cell_data['parts']['decimals']);
