@@ -29,12 +29,13 @@ use Widgets\ItemHistory\Includes\{
 };
 
 $table = (new CTableInfo())->addClass($data['show_thumbnail'] ? 'show-thumbnail' : null);
-$is_layout_vertical = $data['layout'] == WidgetForm::LAYOUT_VERTICAL;
 
 if ($data['error'] !== null) {
 	$table->setNoDataMessage($data['error']);
 }
 else {
+	$is_layout_vertical = $data['layout'] == WidgetForm::LAYOUT_VERTICAL;
+
 	if ($data['show_column_header'] != WidgetForm::COLUMN_HEADER_OFF) {
 		$table_header = [];
 
@@ -107,6 +108,7 @@ else {
 
 	if ($is_layout_vertical) {
 		$column_indexes = array_keys($data['columns']);
+		$column_count = count($data['columns']);
 
 		foreach ($rows as $row) {
 			$table_row = [];
@@ -120,7 +122,7 @@ else {
 			foreach ($column_indexes as $index) {
 				if (array_key_exists($index, $row)) {
 					$table_row = array_merge($table_row,
-						makeValueCell($data['columns'][$index], $row[$index], 'has-broadcast-data')
+						makeValueCell($data['columns'][$index], $row[$index], $column_count > 1, 'has-broadcast-data')
 					);
 				}
 				else {
@@ -148,6 +150,7 @@ else {
 					]))
 						->addClass('has-broadcast-data')
 						->setAttribute('data-itemid', $item_value['itemid'])
+						->setAttribute('data-key_', $item_value['key_'])
 						->setAttribute('data-clock', $clock.'.'.$item_value['ns'])
 				);
 		}
@@ -177,7 +180,8 @@ function getRowClock(array $columns, array $row): string | int {
 	return reset($row)['clock'];
 }
 
-function makeValueCell(array $column, array $item_value, string $cell_class = null): array {
+function makeValueCell(array $column, array $item_value, bool $text_wordbreak = false,
+		string $cell_class = null): array {
 	$color = $column['base_color'];
 
 	switch ($column['item_value_type']) {
@@ -205,6 +209,7 @@ function makeValueCell(array $column, array $item_value, string $cell_class = nu
 					(new CCol($bar_gauge))
 						->addClass($cell_class)
 						->setAttribute('data-itemid', $item_value['itemid'])
+						->setAttribute('data-key_', $item_value['key_'])
 						->setAttribute('data-clock', $item_value['clock'].'.'.$item_value['ns']),
 					(new CCol(
 						(new CSpan($item_value['formatted_value']))->setHint(
@@ -213,6 +218,7 @@ function makeValueCell(array $column, array $item_value, string $cell_class = nu
 					))
 						->addClass($cell_class)
 						->setAttribute('data-itemid', $item_value['itemid'])
+						->setAttribute('data-key_', $item_value['key_'])
 						->setAttribute('data-clock', $item_value['clock'].'.'.$item_value['ns'])
 						->addStyle('width: 0;')
 						->addClass(ZBX_STYLE_NOWRAP)
@@ -241,6 +247,7 @@ function makeValueCell(array $column, array $item_value, string $cell_class = nu
 					))
 						->addClass($cell_class)
 						->setAttribute('data-itemid', $item_value['itemid'])
+						->setAttribute('data-key_', $item_value['key_'])
 						->setAttribute('data-clock', $item_value['clock'].'.'.$item_value['ns'])
 						->setAttribute('bgcolor', $color !== '' ? '#'.$color : null)
 						->setColSpan(2)
@@ -259,25 +266,48 @@ function makeValueCell(array $column, array $item_value, string $cell_class = nu
 				}
 			}
 
-			$value = $column['display'] == CWidgetFieldColumnsList::DISPLAY_SINGLE_LINE
-				? substr($item_value['value'], 0, $column['max_length'])
-					.(strlen($item_value['value']) > $column['max_length'] ? '...' : '')
-				: $item_value['value'];
+			$cell = new CCol();
+
+			switch ($column['display']) {
+				case CWidgetFieldColumnsList::DISPLAY_AS_IS:
+					$cell
+						->addItem(
+							(new CSpan(zbx_nl2br($item_value['value'])))->setHint(
+								(new CDiv($item_value['value']))->addClass(ZBX_STYLE_HINTBOX_WRAP)
+							)
+						)
+						->addClass($text_wordbreak ? ZBX_STYLE_WORDBREAK : ZBX_STYLE_NOWRAP);
+					break;
+
+				case CWidgetFieldColumnsList::DISPLAY_SINGLE_LINE:
+					$single_line_value = [mb_substr($item_value['value'], 0, $column['max_length'])];
+
+					if (strlen($item_value['value']) > $column['max_length']) {
+						$single_line_value[] = HELLIP();
+					}
+
+					$cell
+						->addItem(
+							(new CSpan($single_line_value))->setHint(
+								(new CDiv($item_value['value']))->addClass(ZBX_STYLE_HINTBOX_WRAP)
+							)
+						)
+						->addClass(ZBX_STYLE_NOWRAP);
+					break;
+
+				case CWidgetFieldColumnsList::DISPLAY_HTML:
+					$cell->addItem(
+						new CJsScript($item_value['value'])
+					);
+					break;
+			}
 
 			return [
-				(new CCol($column['display'] != CWidgetFieldColumnsList::DISPLAY_HTML
-					? (new CSpan($value))->setHint(
-						(new CDiv($item_value['value']))->addClass(ZBX_STYLE_HINTBOX_WRAP)
-					)
-					: new CJsScript($value)
-				))
-					->addClass($column['display'] == CWidgetFieldColumnsList::DISPLAY_SINGLE_LINE
-						? ZBX_STYLE_NOWRAP
-						: null
-					)
+				$cell
 					->addClass($column['monospace_font'] ? ZBX_STYLE_MONOSPACE_FONT : null)
 					->addClass($cell_class)
 					->setAttribute('data-itemid', $item_value['itemid'])
+					->setAttribute('data-key_', $item_value['key_'])
 					->setAttribute('data-clock', $item_value['clock'].'.'.$item_value['ns'])
 					->setAttribute('bgcolor', $color !== '' ? '#'.$color : null)
 					->setColSpan(2)
@@ -294,6 +324,7 @@ function makeValueCell(array $column, array $item_value, string $cell_class = nu
 					->addClass($cell_class)
 					->setAttribute('bgcolor', $color !== '' ? '#'.$color : null)
 					->setAttribute('data-itemid', $item_value['itemid'])
+					->setAttribute('data-key_', $item_value['key_'])
 					->setAttribute('data-clock', $item_value['clock'].'.'.$item_value['ns'])
 					->setColSpan(2)
 			];
