@@ -1,21 +1,16 @@
 <?php declare(strict_types = 0);
 /*
-** Zabbix
 ** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -24,11 +19,12 @@ namespace Widgets\SvgGraph\Actions;
 use CControllerDashboardWidgetView,
 	CControllerResponseData,
 	CNumberParser,
-	CParser,
-	CRangeTimeParser,
-	CSvgGraphHelper;
+	CParser;
 
-use Widgets\SvgGraph\Includes\WidgetForm;
+use Widgets\SvgGraph\Includes\{
+	CSvgGraphHelper,
+	WidgetForm
+};
 
 class WidgetView extends CControllerDashboardWidgetView {
 
@@ -42,53 +38,28 @@ class WidgetView extends CControllerDashboardWidgetView {
 
 		$this->addValidationRules([
 			'edit_mode' => 'in 0,1',
-			'content_width' => 'int32|ge '.self::GRAPH_WIDTH_MIN.'|le '.self::GRAPH_WIDTH_MAX,
-			'content_height' => 'int32|ge '.self::GRAPH_HEIGHT_MIN.'|le '.self::GRAPH_HEIGHT_MAX,
-			'preview' => 'in 1',
-			'from' => 'range_time',
-			'to' => 'range_time'
+			'contents_width' => 'int32|ge '.self::GRAPH_WIDTH_MIN.'|le '.self::GRAPH_WIDTH_MAX,
+			'contents_height' => 'int32|ge '.self::GRAPH_HEIGHT_MIN.'|le '.self::GRAPH_HEIGHT_MAX,
+			'has_custom_time_period' => 'in 1',
+			'preview' => 'in 1'
 		]);
 	}
 
-	protected function checkInput(): bool {
-		$ret = parent::checkInput();
-
-		if ($ret && !$this->getInput('preview', 0)) {
-			$this->addValidationRules([
-				'from' => 'required',
-				'to' => 'required'
-			]);
-
-			return parent::checkInput();
-		}
-
-		return $ret;
-	}
-
 	protected function doAction(): void {
 		$edit_mode = $this->getInput('edit_mode', 0);
-		$width = (int) $this->getInput('content_width', self::GRAPH_WIDTH_MIN);
-		$height = (int) $this->getInput('content_height', self::GRAPH_HEIGHT_MIN);
-		$preview = (bool) $this->getInput('preview', 0); // Configuration preview.
+		$width = (int) $this->getInput('contents_width', self::GRAPH_WIDTH_MIN);
+		$height = (int) $this->getInput('contents_height', self::GRAPH_HEIGHT_MIN);
+		$has_custom_time_period = $this->hasInput('has_custom_time_period');
+		$preview = $this->hasInput('preview'); // Configuration preview.
 
-		$dashboard_time = !WidgetForm::hasOverrideTime($this->fields_values);
-
-		if ($dashboard_time && !$preview) {
-			$from = $this->getInput('from');
-			$to = $this->getInput('to');
-		}
-		else {
-			$from = $this->fields_values['time_from'];
-			$to = $this->fields_values['time_to'];
-		}
-
-		$range_time_parser = new CRangeTimeParser();
-
-		$range_time_parser->parse($from);
-		$time_from = $range_time_parser->getDateTime(true)->getTimestamp();
-
-		$range_time_parser->parse($to);
-		$time_to = $range_time_parser->getDateTime(false)->getTimestamp();
+		// Hide left/right Y axis if it is not used by any dataset.
+		$ds_y_axes = array_column($this->fields_values['ds'], 'axisy', 'axisy');
+		$lefty = array_key_exists(GRAPH_YAXIS_SIDE_LEFT, $ds_y_axes)
+			? $this->fields_values['lefty']
+			: SVG_GRAPH_AXIS_OFF;
+		$righty = array_key_exists(GRAPH_YAXIS_SIDE_RIGHT, $ds_y_axes)
+			? $this->fields_values['righty']
+			: SVG_GRAPH_AXIS_OFF;
 
 		$parser = new CNumberParser(['with_size_suffix' => true, 'with_time_suffix' => true]);
 
@@ -119,7 +90,7 @@ class WidgetView extends CControllerDashboardWidgetView {
 		$graph_data = [
 			'data_sets' => array_values($this->fields_values['ds']),
 			'data_source' => $this->fields_values['source'],
-			'dashboard_time' => $dashboard_time,
+			'fix_time_period' => $has_custom_time_period || $edit_mode,
 			'displaying' => [
 				'show_simple_triggers' => $this->fields_values['simple_triggers'] == SVG_GRAPH_SIMPLE_TRIGGERS_ON,
 				'show_working_time' => $this->fields_values['working_time'] == SVG_GRAPH_WORKING_TIME_ON,
@@ -129,17 +100,19 @@ class WidgetView extends CControllerDashboardWidgetView {
 				'percentile_right_value' => $percentile_right_value
 			],
 			'time_period' => [
-				'time_from' => $time_from,
-				'time_to' => $time_to
+				'time_from' => $this->fields_values['time_period']['from_ts'],
+				'time_to' => $this->fields_values['time_period']['to_ts']
 			],
 			'axes' => [
-				'show_left_y_axis' => $this->fields_values['lefty'] == SVG_GRAPH_AXIS_ON,
+				'show_left_y_axis' => $lefty == SVG_GRAPH_AXIS_ON,
+				'left_y_scale' => $this->fields_values['lefty_scale'],
 				'left_y_min' => $lefty_min,
 				'left_y_max' => $lefty_max,
 				'left_y_units' => $this->fields_values['lefty_units'] == SVG_GRAPH_AXIS_UNITS_STATIC
 					? $this->fields_values['lefty_static_units']
 					: null,
-				'show_right_y_axis' => $this->fields_values['righty'] == SVG_GRAPH_AXIS_ON,
+				'show_right_y_axis' => $righty == SVG_GRAPH_AXIS_ON,
+				'right_y_scale' => $this->fields_values['righty_scale'],
 				'right_y_min' => $righty_min,
 				'right_y_max' => $righty_max,
 				'right_y_units' => $this->fields_values['righty_units'] == SVG_GRAPH_AXIS_UNITS_STATIC
@@ -148,21 +121,27 @@ class WidgetView extends CControllerDashboardWidgetView {
 				'show_x_axis' => $this->fields_values['axisx'] == SVG_GRAPH_AXIS_ON
 			],
 			'legend' => [
-				'show_legend' => $this->fields_values['legend'] == SVG_GRAPH_LEGEND_ON,
+				'show_legend' => $this->fields_values['legend'] == WidgetForm::LEGEND_ON,
 				'legend_columns' => $this->fields_values['legend_columns'],
 				'legend_lines' => $this->fields_values['legend_lines'],
-				'legend_statistic' => $this->fields_values['legend_statistic']
+				'legend_lines_mode' => $this->fields_values['legend_lines_mode'],
+				'legend_statistic' => $this->fields_values['legend_statistic'],
+				'show_aggregation' => $this->fields_values['legend_aggregation'] == WidgetForm::LEGEND_AGGREGATION_ON
 			],
 			'problems' => [
 				'show_problems' => $this->fields_values['show_problems'] == SVG_GRAPH_PROBLEMS_ON,
 				'graph_item_problems' => $this->fields_values['graph_item_problems'] == SVG_GRAPH_SELECTED_ITEM_PROBLEMS,
-				'problemhosts' => $this->fields_values['problemhosts'],
+				'problemhosts' => $this->isTemplateDashboard() ? '' : $this->fields_values['problemhosts'],
 				'severities' => $this->fields_values['severities'],
 				'problem_name' => $this->fields_values['problem_name'],
 				'evaltype' => $this->fields_values['evaltype'],
 				'tags' => $this->fields_values['tags']
 			],
-			'overrides' => array_values($this->fields_values['or'])
+			'overrides' => array_values($this->fields_values['or']),
+			'templateid' => $this->getInput('templateid', ''),
+			'override_hostid' => $this->fields_values['override_hostid']
+				? $this->fields_values['override_hostid'][0]
+				: ''
 		];
 
 		$svg_options = CSvgGraphHelper::get($graph_data, $width, $height);
@@ -172,10 +151,10 @@ class WidgetView extends CControllerDashboardWidgetView {
 
 		if (!$preview) {
 			$svg_options['data'] = zbx_array_merge($svg_options['data'], [
-				'sbox' => $graph_data['dashboard_time'] && !$edit_mode,
+				'sbox' => !$has_custom_time_period && !$edit_mode,
 				'show_problems' => $graph_data['problems']['show_problems'],
 				'show_simple_triggers' => $graph_data['displaying']['show_simple_triggers'],
-				'time_from' => $graph_data['time_period']['time_from'],
+				'time_period' => $this->fields_values['time_period'],
 				'hint_max_rows' => ZBX_WIDGET_ROWS
 			]);
 		}
@@ -198,10 +177,12 @@ class WidgetView extends CControllerDashboardWidgetView {
 	private function makeWidgetInfo(): array {
 		$info = [];
 
-		if (WidgetForm::hasOverrideTime($this->fields_values)) {
+		if ($this->hasInput('has_custom_time_period')) {
 			$info[] = [
-				'icon' => 'btn-info-clock',
-				'hint' => relativeDateToText($this->fields_values['time_from'], $this->fields_values['time_to'])
+				'icon' => ZBX_ICON_TIME_PERIOD,
+				'hint' => relativeDateToText($this->fields_values['time_period']['from'],
+					$this->fields_values['time_period']['to']
+				)
 			];
 		}
 
